# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/deletion.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n qwak/execution/v1/deletion.proto\x12\x1fqwak.feature.store.execution.v1\"\xe9\x02\n\x12\x46\x65\x61turesetDeletion\x12]\n\x19\x62\x61tch_featureset_deletion\x18\x01 \x01(\x0b\x32\x38.qwak.feature.store.execution.v1.BatchFeaturesetDeletionH\x00\x12\x65\n\x1dstreaming_featureset_deletion\x18\x02 \x01(\x0b\x32<.qwak.feature.store.execution.v1.StreamingFeaturesetDeletionH\x00\x12|\n)streaming_aggregation_featureset_deletion\x18\x03 \x01(\x0b\x32G.qwak.feature.store.execution.v1.StreamingAggregationFeaturesetDeletionH\x00\x42\x0f\n\rdeletion_type\"\x19\n\x17\x42\x61tchFeaturesetDeletion\"\x1d\n\x1bStreamingFeaturesetDeletion\"(\n&StreamingAggregationFeaturesetDeletionB)\n%com.qwak.ai.features.execution.api.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.execution.v1.deletion_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.features.execution.api.v1P\001'
  _globals['_FEATURESETDELETION']._serialized_start=70
  _globals['_FEATURESETDELETION']._serialized_end=431
  _globals['_BATCHFEATURESETDELETION']._serialized_start=433
  _globals['_BATCHFEATURESETDELETION']._serialized_end=458
  _globals['_STREAMINGFEATURESETDELETION']._serialized_start=460
  _globals['_STREAMINGFEATURESETDELETION']._serialized_end=489
  _globals['_STREAMINGAGGREGATIONFEATURESETDELETION']._serialized_start=491
  _globals['_STREAMINGAGGREGATIONFEATURESETDELETION']._serialized_end=531
# @@protoc_insertion_point(module_scope)



from typing import Any, Optional

from qwak.exceptions import QwakException
from qwak.feature_store.feature_sets.transformations import BaseTransformation


class FeaturesetUtils:
    @staticmethod
    def validate_base_featureset_decorator(
        user_transformation: Any,
        entity: Optional[str] = None,
        key: Optional[str] = None,
    ):
        if not isinstance(user_transformation, BaseTransformation):
            raise ValueError(
                "Function must return a valid qwak transformation function"
            )
        if (not key) is (not entity):
            raise ValueError(
                "Key and entity are mutually exclusive, please specify only one"
            )

    @staticmethod
    def validate_streaming_featureset_decorator(
        online_trigger_interval: Any, offline_scheduling_policy: Any
    ):
        import croniter

        # verify the cron expression is valid
        if not isinstance(
            offline_scheduling_policy, str
        ) or not croniter.croniter.is_valid(offline_scheduling_policy):
            raise QwakException(
                f"Offline scheduling policy provided '{offline_scheduling_policy}' "
                f"is not a valid cron expression"
            )

        # verify the online scheduling policy is valid
        online_interval = online_trigger_interval
        if not (type(online_interval) is int and online_interval >= 0):
            raise QwakException(
                f"Value '{online_interval}'"
                f" is not a legal online scheduling policy, "
                f"only non-negative integers are allowed"
            )



import uuid

from _qwak_proto.qwak.monitoring.v0.alerting_channel_management_service_pb2 import (
    CreateAlertingChannelRequest,
    CreateAlertingChannelResponse,
    DeleteAlertingChannelRequest,
    DeleteAlertingChannelResponse,
    GetAlertingChannelRequestByName,
    GetAlertingChannelResponseByName,
    ListAlertingChannelRequest,
    ListAlertingChannelResponse,
)
from _qwak_proto.qwak.monitoring.v0.alerting_channel_management_service_pb2_grpc import (
    AlertingChannelManagementServiceServicer,
)
from _qwak_proto.qwak.monitoring.v0.alerting_channel_pb2 import (
    AlertingChannelDescription,
    AlertingChannelMetadata,
)
from qwak_services_mock.mocks.utils.exception_handlers import raise_internal_grpc_error


class AlertsRegistryServiceApiMock(AlertingChannelManagementServiceServicer):
    def __init__(self):
        super(AlertsRegistryServiceApiMock, self).__init__()
        self.alerts_channels = dict()

    def CreateAlertingChannel(self, request: CreateAlertingChannelRequest, context):
        metadata = AlertingChannelMetadata(
            id=str(uuid.uuid4()), name=request.options.name
        )
        self.alerts_channels[request.options.name] = AlertingChannelDescription(
            spec=request.options.spec, metadata=metadata
        )
        return CreateAlertingChannelResponse()

    def GetAlertingChannelByName(
        self, request: GetAlertingChannelRequestByName, context
    ):
        try:
            return GetAlertingChannelResponseByName(
                description=self.alerts_channels[request.name]
            )
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def ListAlertingChannel(self, request: ListAlertingChannelRequest, context):
        try:
            return ListAlertingChannelResponse(
                description=[desc for name, desc in self.alerts_channels.items()]
            )
        except Exception as e:
            raise_internal_grpc_error(context, e)

    def DeleteAlertingChannel(self, request: DeleteAlertingChannelRequest, context):
        try:
            del self.alerts_channels[request.name]
            return DeleteAlertingChannelResponse()
        except Exception as e:
            raise_internal_grpc_error(context, e)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/streaming_aggregation.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.feature_store.features import feature_set_types_pb2 as qwak_dot_feature__store_dot_features_dot_feature__set__types__pb2
from _qwak_proto.qwak.feature_store.features import execution_pb2 as qwak_dot_feature__store_dot_features_dot_execution__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-qwak/execution/v1/streaming_aggregation.proto\x12\x1fqwak.feature.store.execution.v1\x1a\x33qwak/feature_store/features/feature_set_types.proto\x1a+qwak/feature_store/features/execution.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"@\n%RowLevelStreamingAggregationIngestion\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\"\xf8\x01\n\'CompactionStreamingAggregationIngestion\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\x12T\n\x14scheduled_compaction\x18\x02 \x01(\x0b\x32\x34.qwak.feature.store.execution.v1.ScheduledCompactionH\x00\x12N\n\x11manual_compaction\x18\x03 \x01(\x0b\x32\x31.qwak.feature.store.execution.v1.ManualCompactionH\x00\x42\x0e\n\x0ctrigger_type\"\x15\n\x13ScheduledCompaction\"\x12\n\x10ManualCompaction\"\x8b\x03\n%StreamingAggregationBackfillIngestion\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x01 \x01(\t\x12L\n\x0e\x65xecution_spec\x18\x02 \x01(\x0b\x32\x34.qwak.feature.store.features.execution.ExecutionSpec\x12\x33\n\x0fstart_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_timestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x43\n\x0etransformation\x18\x05 \x01(\x0b\x32+.qwak.feature.store.features.Transformation\x12N\n\x11\x64\x61ta_source_specs\x18\x06 \x03(\x0b\x32\x33.qwak.feature.store.execution.v1.BackfillDataSource\"n\n\x12\x42\x61\x63kfillDataSource\x12\x18\n\x10\x64\x61ta_source_name\x18\x01 \x01(\t\x12>\n\ntime_range\x18\x02 \x01(\x0b\x32*.qwak.feature.store.execution.v1.TimeRange\"\x99\x01\n\tTimeRange\x12\x35\n\x0fstart_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x33\n\rend_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x42\x10\n\x0estart_optionalB\x0e\n\x0c\x65nd_optionalB)\n%com.qwak.ai.features.execution.api.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.execution.v1.streaming_aggregation_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.features.execution.api.v1P\001'
  _globals['_ROWLEVELSTREAMINGAGGREGATIONINGESTION']._serialized_start=213
  _globals['_ROWLEVELSTREAMINGAGGREGATIONINGESTION']._serialized_end=277
  _globals['_COMPACTIONSTREAMINGAGGREGATIONINGESTION']._serialized_start=280
  _globals['_COMPACTIONSTREAMINGAGGREGATIONINGESTION']._serialized_end=528
  _globals['_SCHEDULEDCOMPACTION']._serialized_start=530
  _globals['_SCHEDULEDCOMPACTION']._serialized_end=551
  _globals['_MANUALCOMPACTION']._serialized_start=553
  _globals['_MANUALCOMPACTION']._serialized_end=571
  _globals['_STREAMINGAGGREGATIONBACKFILLINGESTION']._serialized_start=574
  _globals['_STREAMINGAGGREGATIONBACKFILLINGESTION']._serialized_end=969
  _globals['_BACKFILLDATASOURCE']._serialized_start=971
  _globals['_BACKFILLDATASOURCE']._serialized_end=1081
  _globals['_TIMERANGE']._serialized_start=1084
  _globals['_TIMERANGE']._serialized_end=1237
# @@protoc_insertion_point(module_scope)



#
#    Copyright 2024 OpenAI
#
#    Licensed under the Apache License, Version 2.0 (the "License");
#    you may not use this file except in compliance with the License.
#    You may obtain a copy of the License at
#
#        http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS,
#    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#    See the License for the specific language governing permissions and
#    limitations under the License.

from dataclasses import dataclass
from typing import List, Optional

from qwak.llmops.generation.base import ModelResponse
from .chat_completion_token_logprob import ChatCompletionTokenLogprob

__all__ = [
    "ChatCompletionChunk",
    "Choice",
    "ChoiceDelta",
    "ChoiceDeltaFunctionCall",
    "ChoiceDeltaToolCall",
    "ChoiceDeltaToolCallFunction",
    "ChoiceLogprobs",
]


@dataclass
class ChoiceDeltaFunctionCall:
    arguments: Optional[str] = None
    """
    The arguments to call the function with, as generated by the model in JSON
    format. Note that the model does not always generate valid JSON, and may
    hallucinate parameters not defined by your function schema. Validate the
    arguments in your code before calling your function.
    """

    name: Optional[str] = None
    """The name of the function to call."""


@dataclass
class ChoiceDeltaToolCallFunction:
    arguments: Optional[str] = None
    """
    The arguments to call the function with, as generated by the model in JSON
    format. Note that the model does not always generate valid JSON, and may
    hallucinate parameters not defined by your function schema. Validate the
    arguments in your code before calling your function.
    """

    name: Optional[str] = None
    """The name of the function to call."""


@dataclass
class ChoiceDeltaToolCall:
    index: int

    id: Optional[str] = None
    """The ID of the tool call."""

    function: Optional[ChoiceDeltaToolCallFunction] = None

    type: Optional[str] = None
    """The type of the tool. Currently, only `function` is supported."""

    def __post_init__(self):
        """Validates that type is 'function' if present."""
        if self.type is not None and self.type != "function":
            raise ValueError(
                f"Invalid type: '{self.type}'. Must be 'function' or None."
            )


@dataclass
class ChoiceDelta:
    content: Optional[str] = None
    """The contents of the chunk message."""

    function_call: Optional[ChoiceDeltaFunctionCall] = None
    """Deprecated and replaced by `tool_calls`.

    The name and arguments of a function that should be called, as generated by the
    model.
    """

    role: Optional[str] = None
    """The role of the author of this message."""

    tool_calls: Optional[List[ChoiceDeltaToolCall]] = None

    def __post_init__(self):
        """Validates that role is one of the allowed values if present."""
        if self.role is not None:
            allowed_roles = {"system", "user", "assistant", "tool"}
            if self.role not in allowed_roles:
                raise ValueError(
                    f"Invalid role: '{self.role}'. "
                    f"Must be one of {allowed_roles} or None."
                )


@dataclass
class ChoiceLogprobs:
    content: Optional[List[ChatCompletionTokenLogprob]] = None
    """A list of message content tokens with log probability information."""


@dataclass
class Choice:
    delta: ChoiceDelta
    """A chat completion delta generated by streamed model responses."""

    index: int
    """The index of the choice in the list of choices."""

    finish_reason: Optional[str] = None
    """The reason the model stopped generating tokens.

    This will be `stop` if the model hit a natural stop point or a provided stop
    sequence, `length` if the maximum number of tokens specified in the request was
    reached, `content_filter` if content was omitted due to a flag from our content
    filters, `tool_calls` if the model called a tool, or `function_call`
    (deprecated) if the model called a function.
    """

    logprobs: Optional[ChoiceLogprobs] = None
    """Log probability information for the choice."""

    def __post_init__(self):
        """Validates that finish_reason is one of the allowed values if present."""
        if self.finish_reason is not None:
            allowed_reasons = {
                "stop",
                "length",
                "tool_calls",
                "content_filter",
                "function_call",
            }
            if self.finish_reason not in allowed_reasons:
                raise ValueError(
                    f"Invalid finish_reason: '{self.finish_reason}'. "
                    f"Must be one of {allowed_reasons} or None."
                )


@dataclass
class ChatCompletionChunk(ModelResponse):
    id: str
    """A unique identifier for the chat completion. Each chunk has the same ID."""

    choices: List[Choice]
    """A list of chat completion choices.

    Can be more than one if `n` is greater than 1.
    """

    created: int
    """The Unix timestamp (in seconds) of when the chat completion was created.

    Each chunk has the same timestamp.
    """

    model: str
    """The model to generate the completion."""

    object: str
    """The object type, which is always `chat.completion.chunk`."""

    system_fingerprint: Optional[str] = None
    """
    This fingerprint represents the backend configuration that the model runs with.
    Can be used in conjunction with the `seed` request parameter to understand when
    backend changes have been made that might impact determinism.
    """

    def __post_init__(self):
        """Validates that the object type is correct."""
        if self.object != "chat.completion.chunk":
            raise ValueError(
                f"Invalid object type: '{self.object}'. Must be 'chat.completion.chunk'"
            )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/jobs/job.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.execution.v1 import backfill_pb2 as qwak_dot_execution_dot_v1_dot_backfill__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n qwak/execution/v1/jobs/job.proto\x12$qwak.feature.store.execution.v1.jobs\x1a\x1fgoogle/protobuf/timestamp.proto\x1a qwak/execution/v1/backfill.proto\"\xc0\x05\n\tJobRecord\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x17\n\rlegacy_run_id\x18\x02 \x01(\x03H\x00\x12\x16\n\x0c\x65xecution_id\x18\x03 \x01(\tH\x00\x12\x17\n\x0f\x66\x65\x61tureset_name\x18\x04 \x01(\t\x12\x15\n\rfeatureset_id\x18\x05 \x01(\t\x12\x16\n\x0e\x65nvironment_id\x18\x06 \x01(\t\x12\x12\n\naccount_id\x18\x07 \x01(\t\x12\x43\n\njob_status\x18\x08 \x01(\x0e\x32/.qwak.feature.store.execution.v1.jobs.JobStatus\x12\x31\n\rcreation_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstart_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12G\n\x0cjob_metadata\x18\x0c \x01(\x0b\x32\x31.qwak.feature.store.execution.v1.jobs.JobMetadata\x12R\n\njob_labels\x18\r \x03(\x0b\x32>.qwak.feature.store.execution.v1.jobs.JobRecord.JobLabelsEntry\x12\x0c\n\x04\x63ode\x18\x0e \x01(\t\x12H\n\x04info\x18\x0f \x01(\x0b\x32\x38.qwak.feature.store.execution.v1.jobs.FailureInformationH\x01\x1a\x30\n\x0eJobLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\t\n\x07\x65xec_idB\x0e\n\x0c\x66\x61ilure_info\"\xad\x03\n\x0bJobMetadata\x12`\n\x18\x62\x61tch_ingestion_metadata\x18\x01 \x01(\x0b\x32<.qwak.feature.store.execution.v1.jobs.BatchIngestionMetadataH\x00\x12h\n!batch_backfill_ingestion_metadata\x18\x02 \x01(\x0b\x32;.qwak.feature.store.execution.v1.jobs.BatchBackfillMetadataH\x00\x12^\n\x17\x62\x61tch_deletion_metadata\x18\x03 \x01(\x0b\x32;.qwak.feature.store.execution.v1.jobs.BatchDeletionMetadataH\x00\x12\x44\n\x1e\x65xpiration_watermark_timestamp\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x42\x0f\n\rmetadata_typeB\x1b\n\x19\x64\x61ta_retention_state_type\"\x9d\x01\n\x15\x42\x61tchDeletionMetadata\x12!\n\x19\x64\x65letion_candidates_table\x18\x01 \x01(\t\x12\x32\n*deletion_candidates_size_in_bytes_on_redis\x18\x02 \x01(\x03\x12-\n%billing_size_in_bytes_before_deletion\x18\x03 \x01(\x03\"\xe7\x01\n\x16\x42\x61tchIngestionMetadata\x12<\n\x18ingested_data_start_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16ingested_data_end_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x19\n\x11num_affected_rows\x18\x03 \x01(\x03\x12\x38\n\x14\x62\x61tch_execution_date\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xd6\x03\n\x15\x42\x61tchBackfillMetadata\x12\x19\n\x11num_interval_rows\x18\x01 \x01(\x03\x12\x44\n\rbackfill_spec\x18\x02 \x01(\x0b\x32-.qwak.feature.store.execution.v1.BackfillSpec\x12\x19\n\x11num_affected_rows\x18\x03 \x01(\x03\x12\x41\n\x1doffline_processing_start_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\x1boffline_processing_end_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12@\n\x1conline_processing_start_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12>\n\x1aonline_processing_end_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x17last_batch_logical_date\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"b\n\x12\x46\x61ilureInformation\x12\x1e\n\x16original_error_message\x18\x01 \x01(\t\x12\x11\n\x07message\x18\x02 \x01(\tH\x00\x42\x19\n\x17\x66ormatted_error_message*\xac\x01\n\tJobStatus\x12\x16\n\x12JOB_STATUS_INVALID\x10\x00\x12\x18\n\x14JOB_STATUS_COMPLETED\x10\x03\x12\x15\n\x11JOB_STATUS_FAILED\x10\x04\x12\x18\n\x14JOB_STATUS_TOO_EARLY\x10\x05\x12\x1d\n\x19LEGACY_JOB_STATUS_RUNNING\x10\x06\x12\x1d\n\x19LEGACY_JOB_STATUS_PENDING\x10\x07\x42G\n*com.qwak.ai.features.execution.api.v1.jobsP\x01Z\x17qwak/fsexecution;fsjobsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.execution.v1.jobs.job_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*com.qwak.ai.features.execution.api.v1.jobsP\001Z\027qwak/fsexecution;fsjobs'
  _JOBRECORD_JOBLABELSENTRY._options = None
  _JOBRECORD_JOBLABELSENTRY._serialized_options = b'8\001'
  _globals['_JOBSTATUS']._serialized_start=2248
  _globals['_JOBSTATUS']._serialized_end=2420
  _globals['_JOBRECORD']._serialized_start=142
  _globals['_JOBRECORD']._serialized_end=846
  _globals['_JOBRECORD_JOBLABELSENTRY']._serialized_start=771
  _globals['_JOBRECORD_JOBLABELSENTRY']._serialized_end=819
  _globals['_JOBMETADATA']._serialized_start=849
  _globals['_JOBMETADATA']._serialized_end=1278
  _globals['_BATCHDELETIONMETADATA']._serialized_start=1281
  _globals['_BATCHDELETIONMETADATA']._serialized_end=1438
  _globals['_BATCHINGESTIONMETADATA']._serialized_start=1441
  _globals['_BATCHINGESTIONMETADATA']._serialized_end=1672
  _globals['_BATCHBACKFILLMETADATA']._serialized_start=1675
  _globals['_BATCHBACKFILLMETADATA']._serialized_end=2145
  _globals['_FAILUREINFORMATION']._serialized_start=2147
  _globals['_FAILUREINFORMATION']._serialized_end=2245
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/build/v1/build.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.builds import build_pb2 as qwak_dot_builds_dot_build__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19qwak/build/v1/build.proto\x12\x11\x63om.qwak.build.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17qwak/builds/build.proto\"\xda\x01\n\x0bModelSchema\x12+\n\x08\x65ntities\x18\x01 \x03(\x0b\x32\x19.com.qwak.build.v1.Entity\x12,\n\x08\x66\x65\x61tures\x18\x02 \x03(\x0b\x32\x1a.com.qwak.build.v1.Feature\x12\x32\n\x0bpredictions\x18\x03 \x03(\x0b\x32\x1d.com.qwak.build.v1.Prediction\x12<\n\x10inference_output\x18\x04 \x03(\x0b\x32\".com.qwak.build.v1.InferenceOutput\"B\n\x06\x45ntity\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0b\x32\x1c.com.qwak.build.v1.ValueType\"\xa8\x04\n\x07\x46\x65\x61ture\x12\x38\n\rbatch_feature\x18\x01 \x01(\x0b\x32\x1f.com.qwak.build.v1.BatchFeatureH\x00\x12>\n\x10\x65xplicit_feature\x18\x02 \x01(\x0b\x32\".com.qwak.build.v1.ExplicitFeatureH\x00\x12@\n\x12on_the_fly_feature\x18\x03 \x01(\x0b\x32\".com.qwak.build.v1.OnTheFlyFeatureH\x00\x12@\n\x11streaming_feature\x18\x04 \x01(\x0b\x32#.com.qwak.build.v1.StreamingFeatureH\x00\x12\x38\n\rrequest_input\x18\x05 \x01(\x0b\x32\x1f.com.qwak.build.v1.RequestInputH\x00\x12W\n\x1dstreaming_aggregation_feature\x18\x06 \x01(\x0b\x32..com.qwak.build.v1.StreamingAggregationFeatureH\x00\x12=\n\x10\x62\x61tch_feature_v1\x18\x07 \x01(\x0b\x32!.com.qwak.build.v1.BatchFeatureV1H\x00\x12\x45\n\x14streaming_feature_v1\x18\x08 \x01(\x0b\x32%.com.qwak.build.v1.StreamingFeatureV1H\x00\x42\x06\n\x04type\"\x85\x01\n\x0fOnTheFlyFeature\x12)\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x19.com.qwak.build.v1.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x39\n\x0fsource_features\x18\x03 \x03(\x0b\x32 .com.qwak.build.v1.SourceFeature\"I\n\x0e\x42\x61tchFeatureV1\x12)\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x19.com.qwak.build.v1.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"M\n\x12StreamingFeatureV1\x12)\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x19.com.qwak.build.v1.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"G\n\x0c\x42\x61tchFeature\x12)\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x19.com.qwak.build.v1.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"K\n\x10StreamingFeature\x12)\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x19.com.qwak.build.v1.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"V\n\x1bStreamingAggregationFeature\x12)\n\x06\x65ntity\x18\x01 \x01(\x0b\x32\x19.com.qwak.build.v1.Entity\x12\x0c\n\x04name\x18\x02 \x01(\t\"K\n\x0f\x45xplicitFeature\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0b\x32\x1c.com.qwak.build.v1.ValueType\"H\n\x0cRequestInput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0b\x32\x1c.com.qwak.build.v1.ValueType\"\x91\x01\n\rSourceFeature\x12>\n\x10\x65xplicit_feature\x18\x01 \x01(\x0b\x32\".com.qwak.build.v1.ExplicitFeatureH\x00\x12\x38\n\rrequest_input\x18\x02 \x01(\x0b\x32\x1f.com.qwak.build.v1.RequestInputH\x00\x42\x06\n\x04type\"F\n\nPrediction\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0b\x32\x1c.com.qwak.build.v1.ValueType\"K\n\x0fInferenceOutput\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x04type\x18\x02 \x01(\x0b\x32\x1c.com.qwak.build.v1.ValueType\"\xa1\x01\n\tValueType\x12\x30\n\x04type\x18\x01 \x01(\x0e\x32\".com.qwak.build.v1.ValueType.Types\"b\n\x05Types\x12\x0b\n\x07INVALID\x10\x00\x12\t\n\x05\x42YTES\x10\x01\x12\n\n\x06STRING\x10\x02\x12\t\n\x05INT32\x10\x03\x12\t\n\x05INT64\x10\x04\x12\n\n\x06\x44OUBLE\x10\x05\x12\t\n\x05\x46LOAT\x10\x06\x12\x08\n\x04\x42OOL\x10\x07\"j\n\x11ParameterCategory\"U\n\x08\x43\x61tegory\x12\x0b\n\x07INVALID\x10\x00\x12\n\n\x06\x45NTITY\x10\x01\x12\x0b\n\x07\x46\x45\x41TURE\x10\x02\x12\x0e\n\nPREDICTION\x10\x03\x12\x13\n\x0fINFERENCEOUTPUT\x10\x04\"\x9c\x07\n\x05\x42uild\x12\x0f\n\x07\x62uildId\x18\x01 \x01(\t\x12\x10\n\x08\x63ommitId\x18\x02 \x01(\t\x12\x10\n\x08\x62ranchId\x18\x03 \x01(\t\x12\x13\n\x0b\x62uildConfig\x18\x04 \x01(\t\x12\x34\n\x0c\x62uild_status\x18\x05 \x01(\x0e\x32\x1e.com.qwak.build.v1.BuildStatus\x12\x0c\n\x04tags\x18\x06 \x03(\t\x12\r\n\x05steps\x18\x07 \x03(\t\x12\x34\n\x06params\x18\x08 \x03(\x0b\x32$.com.qwak.build.v1.Build.ParamsEntry\x12\x36\n\x07metrics\x18\t \x03(\x0b\x32%.com.qwak.build.v1.Build.MetricsEntry\x12\x34\n\x0cmodel_schema\x18\n \x01(\x0b\x32\x1e.com.qwak.build.v1.ModelSchema\x12\'\n\x05\x61udit\x18\x0b \x01(\x0b\x32\x18.com.qwak.build.v1.Audit\x12\x12\n\nmodel_uuid\x18\x0c \x01(\t\x12\x13\n\x0bsdk_version\x18\r \x01(\t\x12\x16\n\x0eimage_name_tag\x18\x0e \x01(\t\x12J\n\x1b\x62uild_configuration_message\x18\x0f \x01(\x0b\x32%.com.qwak.build.v1.BuildConfiguration\x12,\n\x08\x65nd_date\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0e\x65nvironment_id\x18\x11 \x01(\t\x12\x1c\n\x14\x62uild_destined_image\x18\x12 \x01(\t\x12;\n\x10\x66ramework_models\x18\x13 \x03(\x0b\x32!.com.qwak.build.v1.FrameworkModel\x12(\n build_destined_image_pull_secret\x18\x14 \x01(\t\x12\x1b\n\x13\x66\x61ilure_reason_code\x18\x15 \x01(\t\x12\x12\n\nbuild_name\x18\x16 \x01(\t\x12\x15\n\rbuild_version\x18\x17 \x01(\x03\x12\x10\n\x08\x64uration\x18\x18 \x01(\x03\x12\x18\n\x10model_version_id\x18\x19 \x01(\t\x1a-\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02:\x02\x38\x01\"\x9b\x01\n\x05\x41udit\x12\x12\n\ncreated_by\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10last_modified_by\x18\x03 \x01(\t\x12\x34\n\x10last_modified_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xb3\x02\n\x12\x42uildConfiguration\x12<\n\x10\x62uild_properties\x18\x01 \x01(\x0b\x32\".com.qwak.build.v1.BuildProperties\x12\x36\n\tbuild_env\x18\x02 \x01(\x0b\x32#.com.qwak.build.v1.BuildEnvironment\x12\x36\n\tpre_build\x18\x03 \x01(\x0b\x32#.com.qwak.build.v1.BuildEnvironment\x12\x37\n\npost_build\x18\x04 \x01(\x0b\x32#.com.qwak.build.v1.BuildEnvironment\x12%\n\x04step\x18\x05 \x01(\x0b\x32\x17.com.qwak.build.v1.Step\x12\x0f\n\x07verbose\x18\x06 \x01(\x05\"\xba\x01\n\x0f\x42uildProperties\x12\x10\n\x08model_id\x18\x01 \x01(\t\x12\x33\n\tmodel_uri\x18\x02 \x01(\x0b\x32 .com.qwak.build.v1.BuildModelUri\x12\x0c\n\x04tags\x18\x03 \x03(\t\x12\x10\n\x08\x62uild_id\x18\x04 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x05 \x01(\t\x12\x18\n\x10\x65nvironment_name\x18\x06 \x01(\t\x12\x16\n\x0egpu_compatible\x18\x07 \x01(\x08\"g\n\rBuildModelUri\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x12\n\ngit_branch\x18\x02 \x01(\t\x12\x10\n\x08main_dir\x18\x03 \x01(\t\x12#\n\x1b\x64\x65pendency_required_folders\x18\x04 \x03(\t\"\xd4\x01\n\x10\x42uildEnvironment\x12.\n\x06\x64ocker\x18\x01 \x01(\x0b\x32\x1e.com.qwak.build.v1.DockerBuild\x12,\n\x05local\x18\x02 \x01(\x0b\x32\x1d.com.qwak.build.v1.LocalBuild\x12\x32\n\npython_env\x18\x03 \x01(\x0b\x32\x1e.com.qwak.build.v1.PythonBuild\x12.\n\x06remote\x18\x04 \x01(\x0b\x32\x1e.com.qwak.build.v1.RemoteBuild\"\xae\x02\n\x0b\x44ockerBuild\x12\x12\n\nbase_image\x18\x01 \x01(\t\x12\x41\n\nbuild_args\x18\x02 \x03(\x0b\x32-.com.qwak.build.v1.DockerBuild.BuildArgsEntry\x12\x10\n\x08\x65nv_vars\x18\x03 \x03(\t\x12\x10\n\x08no_cache\x18\x04 \x01(\x08\x12\x0e\n\x06params\x18\x05 \x03(\t\x12\x1c\n\x14\x61ssumed_iam_role_arn\x18\x06 \x01(\t\x12\r\n\x05\x63\x61\x63he\x18\x07 \x01(\x08\x12\x0c\n\x04push\x18\x08 \x01(\x08\x12\'\n\x1fservice_account_key_secret_name\x18\t \x01(\t\x1a\x30\n\x0e\x42uildArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"2\n\nLocalBuild\x12\x13\n\x0b\x61ws_profile\x18\x01 \x01(\t\x12\x0f\n\x07no_push\x18\x02 \x01(\x08\"\x8c\x02\n\x0bPythonBuild\x12 \n\x18qwak_sdk_extra_index_url\x18\x01 \x01(\t\x12>\n\nvirtualenv\x18\x02 \x01(\x0b\x32*.com.qwak.build.v1.VirtualEnvironmentBuild\x12,\n\x05\x63onda\x18\x03 \x01(\x0b\x32\x1d.com.qwak.build.v1.CondaBuild\x12.\n\x06poetry\x18\x04 \x01(\x0b\x32\x1e.com.qwak.build.v1.PoetryBuild\x12\x1c\n\x14\x64\x65pendency_file_path\x18\x05 \x01(\t\x12\x1f\n\x17use_deprecated_resolver\x18\x06 \x01(\x08\" \n\nCondaBuild\x12\x12\n\nconda_file\x18\x01 \x01(\t\"8\n\x0bPoetryBuild\x12\x16\n\x0epython_version\x18\x01 \x01(\t\x12\x11\n\tlock_file\x18\x02 \x01(\t\"K\n\x17VirtualEnvironmentBuild\x12\x16\n\x0epython_version\x18\x01 \x01(\t\x12\x18\n\x10requirements_txt\x18\x02 \x01(\t\"\\\n\x0bRemoteBuild\x12\x11\n\tis_remote\x18\x01 \x01(\x08\x12:\n\tresources\x18\x02 \x01(\x0b\x32\'.com.qwak.build.v1.RemoteBuildResources\"\x8f\x01\n\x14RemoteBuildResources\x12\x0c\n\x04\x63pus\x18\x01 \x01(\x02\x12\x0e\n\x06memory\x18\x02 \x01(\t\x12\x33\n\x08gpu_type\x18\x03 \x01(\x0e\x32!.qwak.builds.orchestrator.GpuType\x12\x12\n\ngpu_amount\x18\x04 \x01(\x05\x12\x10\n\x08instance\x18\x05 \x01(\t\"_\n\x04Step\x12\r\n\x05tests\x18\x01 \x01(\x08\x12\x1f\n\x17validate_build_artifact\x18\x02 \x01(\x08\x12\'\n\x1fvalidate_build_artifact_timeout\x18\x03 \x01(\x05\"\xf7\x01\n\x0b\x42uildFilter\x12\x0c\n\x04tags\x18\x01 \x03(\t\x12\x37\n\x0emetric_filters\x18\x02 \x03(\x0b\x32\x1f.com.qwak.build.v1.MetricFilter\x12=\n\x11parameter_filters\x18\x03 \x03(\x0b\x32\".com.qwak.build.v1.ParameterFilter\x12\x18\n\x10require_all_tags\x18\x04 \x01(\x08\x12\x1a\n\x12include_extra_tags\x18\x05 \x01(\x08\x12\x11\n\tbuild_ids\x18\x06 \x03(\t\x12\x19\n\x11model_version_ids\x18\x07 \x03(\t\"r\n\x0cMetricFilter\x12\x13\n\x0bmetric_name\x18\x01 \x01(\t\x12\x14\n\x0cmetric_value\x18\x02 \x01(\x02\x12\x37\n\x08operator\x18\x03 \x01(\x0e\x32%.com.qwak.build.v1.MetricOperatorType\"~\n\x0fParameterFilter\x12\x16\n\x0eparameter_name\x18\x01 \x01(\t\x12\x17\n\x0fparameter_value\x18\x02 \x01(\t\x12:\n\x08operator\x18\x03 \x01(\x0e\x32(.com.qwak.build.v1.ParameterOperatorType\"d\n\x13\x46rameworkModelsSpec\x12\x10\n\x08\x62uild_id\x18\x01 \x01(\t\x12;\n\x10\x66ramework_models\x18\x02 \x03(\x0b\x32!.com.qwak.build.v1.FrameworkModel\"c\n\x0e\x46rameworkModel\x12I\n\x16huggingface_model_spec\x18\x02 \x01(\x0b\x32\'.com.qwak.build.v1.HuggingFaceModelSpecH\x00\x42\x06\n\x04type\"]\n\x14HuggingFaceModelSpec\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x12\n\nrepository\x18\x02 \x01(\t\x12\x12\n\nmodel_name\x18\x03 \x01(\t\x12\x0c\n\x04sha1\x18\x04 \x01(\t\"r\n\x11ScanResultSummary\x12(\n\x06issues\x18\x01 \x03(\x0b\x32\x18.com.qwak.build.v1.Issue\x12\x16\n\x0eui_direct_link\x18\x02 \x01(\t\x12\x1b\n\x13ui_scan_direct_link\x18\x03 \x01(\t\"a\n\x05Issue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08severity\x18\x02 \x01(\t\x12\x12\n\nissue_type\x18\x03 \x01(\t\x12\x0f\n\x07summary\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\"L\n\x11\x42uildImageDetails\x12\x17\n\x0fimage_full_path\x18\x01 \x01(\t\x12\x1e\n\x16image_pull_secret_name\x18\x02 \x01(\t\"\x9b\x04\n\x0fScanRequestType\x12\\\n scan_software_components_request\x18\x01 \x01(\x0b\x32\x30.com.qwak.build.v1.ScanSoftwareComponentsRequestH\x00\x12U\n\x1cscan_vulnerabilities_request\x18\x02 \x01(\x0b\x32-.com.qwak.build.v1.ScanVulnerabilitiesRequestH\x00\x12Z\n\x1fscan_malicious_packages_request\x18\x03 \x01(\x0b\x32/.com.qwak.build.v1.ScanMaliciousPackagesRequestH\x00\x12X\n\x1escan_policy_violations_request\x18\x04 \x01(\x0b\x32..com.qwak.build.v1.ScanPolicyViolationsRequestH\x00\x12\x43\n\x13scan_status_request\x18\x05 \x01(\x0b\x32$.com.qwak.build.v1.ScanStatusRequestH\x00\x12P\n\x1ascan_feature_state_request\x18\x06 \x01(\x0b\x32*.com.qwak.build.v1.ScanFeatureStateRequestH\x00\x42\x06\n\x04type\"\x1f\n\x1dScanSoftwareComponentsRequest\"\x1c\n\x1aScanVulnerabilitiesRequest\"\x1e\n\x1cScanMaliciousPackagesRequest\"\x1d\n\x1bScanPolicyViolationsRequest\"\x13\n\x11ScanStatusRequest\"/\n\x17ScanFeatureStateRequest\x12\x14\n\x0c\x66\x65\x61ture_name\x18\x01 \x01(\t*\xad\x02\n\x0b\x42uildStatus\x12\x0b\n\x07INVALID\x10\x00\x12\x0f\n\x0bIN_PROGRESS\x10\x01\x12\x0e\n\nSUCCESSFUL\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\x1d\n\x19REMOTE_BUILD_INITIALIZING\x10\x04\x12\x1a\n\x16REMOTE_BUILD_CANCELLED\x10\x05\x12\x1a\n\x16REMOTE_BUILD_TIMED_OUT\x10\x06\x12\x18\n\x14REMOTE_BUILD_UNKNOWN\x10\x07\x12\x18\n\x14SYNCING_ENVIRONMENTS\x10\x08\x12\x14\n\x10\x46INISHED_SYNCING\x10\t\x12\x13\n\x0f\x42UILD_REQUESTED\x10\n\x12\x11\n\rBUILD_PENDING\x10\x0b\x12\x1b\n\x17\x46\x41ILED_INITIATING_BUILD\x10\x0c*\xa0\x02\n\x12MetricOperatorType\x12 \n\x1cMETRIC_OPERATOR_TYPE_INVALID\x10\x00\x12\x1f\n\x1bMETRIC_OPERATOR_TYPE_EQUALS\x10\x01\x12#\n\x1fMETRIC_OPERATOR_TYPE_NOT_EQUALS\x10\x02\x12\"\n\x1eMETRIC_OPERATOR_TYPE_LESS_THAN\x10\x03\x12)\n%METRIC_OPERATOR_TYPE_LESS_THAN_EQUALS\x10\x04\x12%\n!METRIC_OPERATOR_TYPE_GREATER_THAN\x10\x05\x12,\n(METRIC_OPERATOR_TYPE_GREATER_THAN_EQUALS\x10\x06*\x88\x01\n\x15ParameterOperatorType\x12#\n\x1fPARAMETER_OPERATOR_TYPE_INVALID\x10\x00\x12\"\n\x1ePARAMETER_OPERATOR_TYPE_EQUALS\x10\x01\x12&\n\"PARAMETER_OPERATOR_TYPE_NOT_EQUALS\x10\x02\x42!\n\x11\x63om.qwak.build.v1B\nBuildProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.build.v1.build_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\021com.qwak.build.v1B\nBuildProtoP\001'
  _BUILD_PARAMSENTRY._options = None
  _BUILD_PARAMSENTRY._serialized_options = b'8\001'
  _BUILD_METRICSENTRY._options = None
  _BUILD_METRICSENTRY._serialized_options = b'8\001'
  _DOCKERBUILD_BUILDARGSENTRY._options = None
  _DOCKERBUILD_BUILDARGSENTRY._serialized_options = b'8\001'
  _globals['_BUILDSTATUS']._serialized_start=7060
  _globals['_BUILDSTATUS']._serialized_end=7361
  _globals['_METRICOPERATORTYPE']._serialized_start=7364
  _globals['_METRICOPERATORTYPE']._serialized_end=7652
  _globals['_PARAMETEROPERATORTYPE']._serialized_start=7655
  _globals['_PARAMETEROPERATORTYPE']._serialized_end=7791
  _globals['_MODELSCHEMA']._serialized_start=107
  _globals['_MODELSCHEMA']._serialized_end=325
  _globals['_ENTITY']._serialized_start=327
  _globals['_ENTITY']._serialized_end=393
  _globals['_FEATURE']._serialized_start=396
  _globals['_FEATURE']._serialized_end=948
  _globals['_ONTHEFLYFEATURE']._serialized_start=951
  _globals['_ONTHEFLYFEATURE']._serialized_end=1084
  _globals['_BATCHFEATUREV1']._serialized_start=1086
  _globals['_BATCHFEATUREV1']._serialized_end=1159
  _globals['_STREAMINGFEATUREV1']._serialized_start=1161
  _globals['_STREAMINGFEATUREV1']._serialized_end=1238
  _globals['_BATCHFEATURE']._serialized_start=1240
  _globals['_BATCHFEATURE']._serialized_end=1311
  _globals['_STREAMINGFEATURE']._serialized_start=1313
  _globals['_STREAMINGFEATURE']._serialized_end=1388
  _globals['_STREAMINGAGGREGATIONFEATURE']._serialized_start=1390
  _globals['_STREAMINGAGGREGATIONFEATURE']._serialized_end=1476
  _globals['_EXPLICITFEATURE']._serialized_start=1478
  _globals['_EXPLICITFEATURE']._serialized_end=1553
  _globals['_REQUESTINPUT']._serialized_start=1555
  _globals['_REQUESTINPUT']._serialized_end=1627
  _globals['_SOURCEFEATURE']._serialized_start=1630
  _globals['_SOURCEFEATURE']._serialized_end=1775
  _globals['_PREDICTION']._serialized_start=1777
  _globals['_PREDICTION']._serialized_end=1847
  _globals['_INFERENCEOUTPUT']._serialized_start=1849
  _globals['_INFERENCEOUTPUT']._serialized_end=1924
  _globals['_VALUETYPE']._serialized_start=1927
  _globals['_VALUETYPE']._serialized_end=2088
  _globals['_VALUETYPE_TYPES']._serialized_start=1990
  _globals['_VALUETYPE_TYPES']._serialized_end=2088
  _globals['_PARAMETERCATEGORY']._serialized_start=2090
  _globals['_PARAMETERCATEGORY']._serialized_end=2196
  _globals['_PARAMETERCATEGORY_CATEGORY']._serialized_start=2111
  _globals['_PARAMETERCATEGORY_CATEGORY']._serialized_end=2196
  _globals['_BUILD']._serialized_start=2199
  _globals['_BUILD']._serialized_end=3123
  _globals['_BUILD_PARAMSENTRY']._serialized_start=3030
  _globals['_BUILD_PARAMSENTRY']._serialized_end=3075
  _globals['_BUILD_METRICSENTRY']._serialized_start=3077
  _globals['_BUILD_METRICSENTRY']._serialized_end=3123
  _globals['_AUDIT']._serialized_start=3126
  _globals['_AUDIT']._serialized_end=3281
  _globals['_BUILDCONFIGURATION']._serialized_start=3284
  _globals['_BUILDCONFIGURATION']._serialized_end=3591
  _globals['_BUILDPROPERTIES']._serialized_start=3594
  _globals['_BUILDPROPERTIES']._serialized_end=3780
  _globals['_BUILDMODELURI']._serialized_start=3782
  _globals['_BUILDMODELURI']._serialized_end=3885
  _globals['_BUILDENVIRONMENT']._serialized_start=3888
  _globals['_BUILDENVIRONMENT']._serialized_end=4100
  _globals['_DOCKERBUILD']._serialized_start=4103
  _globals['_DOCKERBUILD']._serialized_end=4405
  _globals['_DOCKERBUILD_BUILDARGSENTRY']._serialized_start=4357
  _globals['_DOCKERBUILD_BUILDARGSENTRY']._serialized_end=4405
  _globals['_LOCALBUILD']._serialized_start=4407
  _globals['_LOCALBUILD']._serialized_end=4457
  _globals['_PYTHONBUILD']._serialized_start=4460
  _globals['_PYTHONBUILD']._serialized_end=4728
  _globals['_CONDABUILD']._serialized_start=4730
  _globals['_CONDABUILD']._serialized_end=4762
  _globals['_POETRYBUILD']._serialized_start=4764
  _globals['_POETRYBUILD']._serialized_end=4820
  _globals['_VIRTUALENVIRONMENTBUILD']._serialized_start=4822
  _globals['_VIRTUALENVIRONMENTBUILD']._serialized_end=4897
  _globals['_REMOTEBUILD']._serialized_start=4899
  _globals['_REMOTEBUILD']._serialized_end=4991
  _globals['_REMOTEBUILDRESOURCES']._serialized_start=4994
  _globals['_REMOTEBUILDRESOURCES']._serialized_end=5137
  _globals['_STEP']._serialized_start=5139
  _globals['_STEP']._serialized_end=5234
  _globals['_BUILDFILTER']._serialized_start=5237
  _globals['_BUILDFILTER']._serialized_end=5484
  _globals['_METRICFILTER']._serialized_start=5486
  _globals['_METRICFILTER']._serialized_end=5600
  _globals['_PARAMETERFILTER']._serialized_start=5602
  _globals['_PARAMETERFILTER']._serialized_end=5728
  _globals['_FRAMEWORKMODELSSPEC']._serialized_start=5730
  _globals['_FRAMEWORKMODELSSPEC']._serialized_end=5830
  _globals['_FRAMEWORKMODEL']._serialized_start=5832
  _globals['_FRAMEWORKMODEL']._serialized_end=5931
  _globals['_HUGGINGFACEMODELSPEC']._serialized_start=5933
  _globals['_HUGGINGFACEMODELSPEC']._serialized_end=6026
  _globals['_SCANRESULTSUMMARY']._serialized_start=6028
  _globals['_SCANRESULTSUMMARY']._serialized_end=6142
  _globals['_ISSUE']._serialized_start=6144
  _globals['_ISSUE']._serialized_end=6241
  _globals['_BUILDIMAGEDETAILS']._serialized_start=6243
  _globals['_BUILDIMAGEDETAILS']._serialized_end=6319
  _globals['_SCANREQUESTTYPE']._serialized_start=6322
  _globals['_SCANREQUESTTYPE']._serialized_end=6861
  _globals['_SCANSOFTWARECOMPONENTSREQUEST']._serialized_start=6863
  _globals['_SCANSOFTWARECOMPONENTSREQUEST']._serialized_end=6894
  _globals['_SCANVULNERABILITIESREQUEST']._serialized_start=6896
  _globals['_SCANVULNERABILITIESREQUEST']._serialized_end=6924
  _globals['_SCANMALICIOUSPACKAGESREQUEST']._serialized_start=6926
  _globals['_SCANMALICIOUSPACKAGESREQUEST']._serialized_end=6956
  _globals['_SCANPOLICYVIOLATIONSREQUEST']._serialized_start=6958
  _globals['_SCANPOLICYVIOLATIONSREQUEST']._serialized_end=6987
  _globals['_SCANSTATUSREQUEST']._serialized_start=6989
  _globals['_SCANSTATUSREQUEST']._serialized_end=7008
  _globals['_SCANFEATURESTATEREQUEST']._serialized_start=7010
  _globals['_SCANFEATURESTATEREQUEST']._serialized_end=7057
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import qwak.ecosystem.v0.azure_credentials_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CloudCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AWS_TEMPORARY_CREDENTIALS_FIELD_NUMBER: builtins.int
    GCP_TEMPORARY_CREDENTIALS_FIELD_NUMBER: builtins.int
    AZURE_TEMPORARY_CREDENTIALS_FIELD_NUMBER: builtins.int
    @property
    def aws_temporary_credentials(self) -> global___AwsTemporaryCredentials: ...
    @property
    def gcp_temporary_credentials(self) -> global___GcpTemporaryCredentials: ...
    @property
    def azure_temporary_credentials(self) -> qwak.ecosystem.v0.azure_credentials_pb2.AzureTemporaryCredentials: ...
    def __init__(
        self,
        *,
        aws_temporary_credentials: global___AwsTemporaryCredentials | None = ...,
        gcp_temporary_credentials: global___GcpTemporaryCredentials | None = ...,
        azure_temporary_credentials: qwak.ecosystem.v0.azure_credentials_pb2.AzureTemporaryCredentials | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aws_temporary_credentials", b"aws_temporary_credentials", "azure_temporary_credentials", b"azure_temporary_credentials", "credentials", b"credentials", "gcp_temporary_credentials", b"gcp_temporary_credentials"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aws_temporary_credentials", b"aws_temporary_credentials", "azure_temporary_credentials", b"azure_temporary_credentials", "credentials", b"credentials", "gcp_temporary_credentials", b"gcp_temporary_credentials"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["credentials", b"credentials"]) -> typing_extensions.Literal["aws_temporary_credentials", "gcp_temporary_credentials", "azure_temporary_credentials"] | None: ...

global___CloudCredentials = CloudCredentials

class AwsTemporaryCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_KEY_ID_FIELD_NUMBER: builtins.int
    SECRET_ACCESS_KEY_FIELD_NUMBER: builtins.int
    SESSION_TOKEN_FIELD_NUMBER: builtins.int
    EXPIRATION_TIME_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    access_key_id: builtins.str
    """Aws access key id"""
    secret_access_key: builtins.str
    """Aws secret access key"""
    session_token: builtins.str
    """Aws session token"""
    @property
    def expiration_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Expiration timestamp of the credentials"""
    region: builtins.str
    """Aws region"""
    def __init__(
        self,
        *,
        access_key_id: builtins.str = ...,
        secret_access_key: builtins.str = ...,
        session_token: builtins.str = ...,
        expiration_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        region: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["expiration_time", b"expiration_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_key_id", b"access_key_id", "expiration_time", b"expiration_time", "region", b"region", "secret_access_key", b"secret_access_key", "session_token", b"session_token"]) -> None: ...

global___AwsTemporaryCredentials = AwsTemporaryCredentials

class GcpTemporaryCredentials(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCESS_TOKEN_FIELD_NUMBER: builtins.int
    EXPIRATION_TIME_FIELD_NUMBER: builtins.int
    access_token: builtins.str
    """Gcp access token"""
    @property
    def expiration_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Expiration timestamp of the credentials"""
    def __init__(
        self,
        *,
        access_token: builtins.str = ...,
        expiration_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["expiration_time", b"expiration_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_token", b"access_token", "expiration_time", b"expiration_time"]) -> None: ...

global___GcpTemporaryCredentials = GcpTemporaryCredentials



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class OAuthTokenCredential(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOKEN_FIELD_NUMBER: builtins.int
    EXPIRED_AT_FIELD_NUMBER: builtins.int
    token: builtins.str
    """The token to use for authentication"""
    @property
    def expired_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Expiration timestamp of the credentials"""
    def __init__(
        self,
        *,
        token: builtins.str = ...,
        expired_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["expired_at", b"expired_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["expired_at", b"expired_at", "token", b"token"]) -> None: ...

global___OAuthTokenCredential = OAuthTokenCredential



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/monitoring/v0/alerting_channel_management_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.monitoring.v0 import alerting_channel_pb2 as qwak_dot_monitoring_dot_v0_dot_alerting__channel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<qwak/monitoring/v0/alerting_channel_management_service.proto\x12\x12qwak.monitoring.v0\x1a)qwak/monitoring/v0/alerting_channel.proto\"a\n\x1c\x43reateAlertingChannelRequest\x12\x41\n\x07options\x18\x01 \x01(\x0b\x32\x30.qwak.monitoring.v0.AlertingChannelCreateOptions\"\x1f\n\x1d\x43reateAlertingChannelResponse\"a\n\x1cUpdateAlertingChannelRequest\x12\x41\n\x07options\x18\x01 \x01(\x0b\x32\x30.qwak.monitoring.v0.AlertingChannelUpdateOptions\"\x1f\n\x1dUpdateAlertingChannelResponse\"+\n\x1dGetAlertingChannelRequestById\x12\n\n\x02id\x18\x01 \x01(\t\"e\n\x1eGetAlertingChannelResponseById\x12\x43\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32..qwak.monitoring.v0.AlertingChannelDescription\"/\n\x1fGetAlertingChannelRequestByName\x12\x0c\n\x04name\x18\x01 \x01(\t\"g\n GetAlertingChannelResponseByName\x12\x43\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32..qwak.monitoring.v0.AlertingChannelDescription\"\x1c\n\x1aListAlertingChannelRequest\"b\n\x1bListAlertingChannelResponse\x12\x43\n\x0b\x64\x65scription\x18\x01 \x03(\x0b\x32..qwak.monitoring.v0.AlertingChannelDescription\",\n\x1c\x44\x65leteAlertingChannelRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x1f\n\x1d\x44\x65leteAlertingChannelResponse2\x9d\x06\n AlertingChannelManagementService\x12|\n\x15\x43reateAlertingChannel\x12\x30.qwak.monitoring.v0.CreateAlertingChannelRequest\x1a\x31.qwak.monitoring.v0.CreateAlertingChannelResponse\x12|\n\x15UpdateAlertingChannel\x12\x30.qwak.monitoring.v0.UpdateAlertingChannelRequest\x1a\x31.qwak.monitoring.v0.UpdateAlertingChannelResponse\x12\x7f\n\x16GetAlertingChannelById\x12\x31.qwak.monitoring.v0.GetAlertingChannelRequestById\x1a\x32.qwak.monitoring.v0.GetAlertingChannelResponseById\x12\x85\x01\n\x18GetAlertingChannelByName\x12\x33.qwak.monitoring.v0.GetAlertingChannelRequestByName\x1a\x34.qwak.monitoring.v0.GetAlertingChannelResponseByName\x12v\n\x13ListAlertingChannel\x12..qwak.monitoring.v0.ListAlertingChannelRequest\x1a/.qwak.monitoring.v0.ListAlertingChannelResponse\x12|\n\x15\x44\x65leteAlertingChannel\x12\x30.qwak.monitoring.v0.DeleteAlertingChannelRequest\x1a\x31.qwak.monitoring.v0.DeleteAlertingChannelResponseB2\n\x1d\x63om.qwak.ai.monitoring.api.v0P\x01Z\x0f.;monitoring_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.monitoring.v0.alerting_channel_management_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.monitoring.api.v0P\001Z\017.;monitoring_v0'
  _globals['_CREATEALERTINGCHANNELREQUEST']._serialized_start=127
  _globals['_CREATEALERTINGCHANNELREQUEST']._serialized_end=224
  _globals['_CREATEALERTINGCHANNELRESPONSE']._serialized_start=226
  _globals['_CREATEALERTINGCHANNELRESPONSE']._serialized_end=257
  _globals['_UPDATEALERTINGCHANNELREQUEST']._serialized_start=259
  _globals['_UPDATEALERTINGCHANNELREQUEST']._serialized_end=356
  _globals['_UPDATEALERTINGCHANNELRESPONSE']._serialized_start=358
  _globals['_UPDATEALERTINGCHANNELRESPONSE']._serialized_end=389
  _globals['_GETALERTINGCHANNELREQUESTBYID']._serialized_start=391
  _globals['_GETALERTINGCHANNELREQUESTBYID']._serialized_end=434
  _globals['_GETALERTINGCHANNELRESPONSEBYID']._serialized_start=436
  _globals['_GETALERTINGCHANNELRESPONSEBYID']._serialized_end=537
  _globals['_GETALERTINGCHANNELREQUESTBYNAME']._serialized_start=539
  _globals['_GETALERTINGCHANNELREQUESTBYNAME']._serialized_end=586
  _globals['_GETALERTINGCHANNELRESPONSEBYNAME']._serialized_start=588
  _globals['_GETALERTINGCHANNELRESPONSEBYNAME']._serialized_end=691
  _globals['_LISTALERTINGCHANNELREQUEST']._serialized_start=693
  _globals['_LISTALERTINGCHANNELREQUEST']._serialized_end=721
  _globals['_LISTALERTINGCHANNELRESPONSE']._serialized_start=723
  _globals['_LISTALERTINGCHANNELRESPONSE']._serialized_end=821
  _globals['_DELETEALERTINGCHANNELREQUEST']._serialized_start=823
  _globals['_DELETEALERTINGCHANNELREQUEST']._serialized_end=867
  _globals['_DELETEALERTINGCHANNELRESPONSE']._serialized_start=869
  _globals['_DELETEALERTINGCHANNELRESPONSE']._serialized_end=900
  _globals['_ALERTINGCHANNELMANAGEMENTSERVICE']._serialized_start=903
  _globals['_ALERTINGCHANNELMANAGEMENTSERVICE']._serialized_end=1700
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/self_service/account/v0/account_membership.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.v0.users import user_pb2 as qwak_dot_administration_dot_v0_dot_users_dot_user__pb2
from _qwak_proto.qwak.self_service.account.v0 import managing_account_pb2 as qwak_dot_self__service_dot_account_dot_v0_dot_managing__account__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5qwak/self_service/account/v0/account_membership.proto\x12\x1cqwak.self_service.account.v0\x1a\'qwak/administration/v0/users/user.proto\x1a\x33qwak/self_service/account/v0/managing_account.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"]\n\rInviteOptions\x12L\n\x0finvitation_spec\x18\x01 \x01(\x0b\x32\x33.qwak.self_service.account.v0.JoiningInvitationSpec\"\xa9\x02\n\x1cJoiningInvitationDescription\x12I\n\x08metadata\x18\x01 \x01(\x0b\x32\x37.qwak.self_service.account.v0.JoiningInvitationMetadata\x12\x41\n\x04spec\x18\x02 \x01(\x0b\x32\x33.qwak.self_service.account.v0.JoiningInvitationSpec\x12\x45\n\x06status\x18\x03 \x01(\x0b\x32\x35.qwak.self_service.account.v0.JoiningInvitationStatus\x12\x1e\n\x16num_of_account_members\x18\x04 \x01(\x05\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x05 \x01(\t\"\xa6\x01\n\x19JoiningInvitationMetadata\x12\x15\n\rinvitation_id\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nexpired_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ninvited_by\x18\x04 \x01(\t\"\x98\x03\n\x15JoiningInvitationSpec\x12\x15\n\rinvitee_email\x18\x01 \x01(\t\x12?\n\x0c\x61\x63\x63ount_role\x18\x02 \x01(\x0e\x32).qwak.administration.user.QwakAccountRole\x12\x17\n\x0f\x65nvironment_ids\x18\x03 \x03(\t\x12\x19\n\x11\x65nvironment_names\x18\x04 \x03(\t\x12z\n\x1d\x65nvironment_id_to_description\x18\x05 \x03(\x0b\x32S.qwak.self_service.account.v0.JoiningInvitationSpec.EnvironmentIdToDescriptionEntry\x1aw\n\x1f\x45nvironmentIdToDescriptionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x43\n\x05value\x18\x02 \x01(\x0b\x32\x34.qwak.self_service.account.v0.EnvironmentDescription:\x02\x38\x01\"\x97\x01\n\x17JoiningInvitationStatus\x12G\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x39.qwak.self_service.account.v0.JoiningInvitationStatusCode\x12\x33\n\x0flast_changed_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x9c\x03\n\x16UserAccountDescription\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x01 \x01(\t\x12\x1a\n\x12is_default_account\x18\x08 \x01(\x08\x12?\n\x0c\x61\x63\x63ount_role\x18\x02 \x01(\x0e\x32).qwak.administration.user.QwakAccountRole\x12\x19\n\x11\x65nvironment_names\x18\x03 \x03(\t\x12{\n\x1d\x65nvironment_id_to_description\x18\x04 \x03(\x0b\x32T.qwak.self_service.account.v0.UserAccountDescription.EnvironmentIdToDescriptionEntry\x1aw\n\x1f\x45nvironmentIdToDescriptionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x43\n\x05value\x18\x02 \x01(\x0b\x32\x34.qwak.self_service.account.v0.EnvironmentDescription:\x02\x38\x01\"w\n\x16\x45nvironmentDescription\x12\x18\n\x10\x65nvironment_name\x18\x01 \x01(\t\x12\x43\n\x0e\x63loud_provider\x18\x02 \x01(\x0e\x32+.qwak.self_service.account.v0.CloudProvider*\x81\x01\n\x1bJoiningInvitationStatusCode\x12*\n&JOINING_INVITATION_STATUS_CODE_INVALID\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\r\n\tCANCELLED\x10\x02\x12\x0c\n\x08\x44\x45\x43LINED\x10\x03\x12\x0c\n\x08\x41\x43\x43\x45PTED\x10\x04\x42\xb9\x01\n#com.qwak.ai.self_service.account.v0P\x01Z\x8f\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/self_service/account/v0;self_service_account_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.self_service.account.v0.account_membership_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#com.qwak.ai.self_service.account.v0P\001Z\217\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/self_service/account/v0;self_service_account_v0'
  _JOININGINVITATIONSPEC_ENVIRONMENTIDTODESCRIPTIONENTRY._options = None
  _JOININGINVITATIONSPEC_ENVIRONMENTIDTODESCRIPTIONENTRY._serialized_options = b'8\001'
  _USERACCOUNTDESCRIPTION_ENVIRONMENTIDTODESCRIPTIONENTRY._options = None
  _USERACCOUNTDESCRIPTION_ENVIRONMENTIDTODESCRIPTIONENTRY._serialized_options = b'8\001'
  _globals['_JOININGINVITATIONSTATUSCODE']._serialized_start=1880
  _globals['_JOININGINVITATIONSTATUSCODE']._serialized_end=2009
  _globals['_INVITEOPTIONS']._serialized_start=214
  _globals['_INVITEOPTIONS']._serialized_end=307
  _globals['_JOININGINVITATIONDESCRIPTION']._serialized_start=310
  _globals['_JOININGINVITATIONDESCRIPTION']._serialized_end=607
  _globals['_JOININGINVITATIONMETADATA']._serialized_start=610
  _globals['_JOININGINVITATIONMETADATA']._serialized_end=776
  _globals['_JOININGINVITATIONSPEC']._serialized_start=779
  _globals['_JOININGINVITATIONSPEC']._serialized_end=1187
  _globals['_JOININGINVITATIONSPEC_ENVIRONMENTIDTODESCRIPTIONENTRY']._serialized_start=1068
  _globals['_JOININGINVITATIONSPEC_ENVIRONMENTIDTODESCRIPTIONENTRY']._serialized_end=1187
  _globals['_JOININGINVITATIONSTATUS']._serialized_start=1190
  _globals['_JOININGINVITATIONSTATUS']._serialized_end=1341
  _globals['_USERACCOUNTDESCRIPTION']._serialized_start=1344
  _globals['_USERACCOUNTDESCRIPTION']._serialized_end=1756
  _globals['_USERACCOUNTDESCRIPTION_ENVIRONMENTIDTODESCRIPTIONENTRY']._serialized_start=1068
  _globals['_USERACCOUNTDESCRIPTION_ENVIRONMENTIDTODESCRIPTIONENTRY']._serialized_end=1187
  _globals['_ENVIRONMENTDESCRIPTION']._serialized_start=1758
  _globals['_ENVIRONMENTDESCRIPTION']._serialized_end=1877
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.administration.account.v1.account_pb2
import qwak.administration.account.v1.jfrog_tenant_details_pb2
import qwak.administration.account.v1.preferences_pb2
import qwak.administration.account.v1.terms_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateAccountRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    PREFERENCES_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    JFROG_TENANT_SPEC_FIELD_NUMBER: builtins.int
    account_name: builtins.str
    """Account name to be created - usually, it will be a name of the company that purchased Qwak"""
    @property
    def preferences(self) -> qwak.administration.account.v1.preferences_pb2.AccountPreferences:
        """The preferences for the account"""
    type: qwak.administration.account.v1.account_pb2.AccountType.ValueType
    """The type of the account"""
    tier: qwak.administration.account.v1.account_pb2.AccountTier.ValueType
    """The tier of the account"""
    @property
    def jfrog_tenant_spec(self) -> qwak.administration.account.v1.jfrog_tenant_details_pb2.JfrogTenantSpec:
        """The JFrog tenant spec"""
    def __init__(
        self,
        *,
        account_name: builtins.str = ...,
        preferences: qwak.administration.account.v1.preferences_pb2.AccountPreferences | None = ...,
        type: qwak.administration.account.v1.account_pb2.AccountType.ValueType = ...,
        tier: qwak.administration.account.v1.account_pb2.AccountTier.ValueType = ...,
        jfrog_tenant_spec: qwak.administration.account.v1.jfrog_tenant_details_pb2.JfrogTenantSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["jfrog_tenant_spec", b"jfrog_tenant_spec", "preferences", b"preferences"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_name", b"account_name", "jfrog_tenant_spec", b"jfrog_tenant_spec", "preferences", b"preferences", "tier", b"tier", "type", b"type"]) -> None: ...

global___CreateAccountRequest = CreateAccountRequest

class CreateAccountResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_FIELD_NUMBER: builtins.int
    @property
    def account(self) -> qwak.administration.account.v1.account_pb2.Account:
        """Created account"""
    def __init__(
        self,
        *,
        account: qwak.administration.account.v1.account_pb2.Account | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["account", b"account"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account", b"account"]) -> None: ...

global___CreateAccountResponse = CreateAccountResponse

class GetAccountRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    account_id: builtins.str
    """Account ID to fetch"""
    def __init__(
        self,
        *,
        account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id"]) -> None: ...

global___GetAccountRequest = GetAccountRequest

class GetAccountResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_FIELD_NUMBER: builtins.int
    @property
    def account(self) -> qwak.administration.account.v1.account_pb2.Account:
        """Fetched account by the requested ID"""
    def __init__(
        self,
        *,
        account: qwak.administration.account.v1.account_pb2.Account | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["account", b"account"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account", b"account"]) -> None: ...

global___GetAccountResponse = GetAccountResponse

class ListAccountsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILTER_FIELD_NUMBER: builtins.int
    @property
    def filter(self) -> qwak.administration.account.v1.account_pb2.ListAccountFilter:
        """Filter to filter account list"""
    def __init__(
        self,
        *,
        filter: qwak.administration.account.v1.account_pb2.ListAccountFilter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["filter", b"filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["filter", b"filter"]) -> None: ...

global___ListAccountsRequest = ListAccountsRequest

class ListAccountsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNTS_FIELD_NUMBER: builtins.int
    @property
    def accounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.administration.account.v1.account_pb2.Account]:
        """All accounts that matched the provided filter"""
    def __init__(
        self,
        *,
        accounts: collections.abc.Iterable[qwak.administration.account.v1.account_pb2.Account] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["accounts", b"accounts"]) -> None: ...

global___ListAccountsResponse = ListAccountsResponse

class UpdateAccountRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    PREFERENCES_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    ACCEPTED_TERMS_FIELD_NUMBER: builtins.int
    JFROG_TENANT_SPEC_FIELD_NUMBER: builtins.int
    account_id: builtins.str
    """The account id to update"""
    @property
    def preferences(self) -> qwak.administration.account.v1.preferences_pb2.AccountPreferences:
        """The preferences for the account"""
    type: qwak.administration.account.v1.account_pb2.AccountType.ValueType
    """The type of the account"""
    tier: qwak.administration.account.v1.account_pb2.AccountTier.ValueType
    """The tier of the account"""
    @property
    def accepted_terms(self) -> qwak.administration.account.v1.terms_pb2.AccountAcceptedTerms:
        """The accepted terms of the account"""
    @property
    def jfrog_tenant_spec(self) -> qwak.administration.account.v1.jfrog_tenant_details_pb2.JfrogTenantSpec:
        """The JFrog tenant spec"""
    def __init__(
        self,
        *,
        account_id: builtins.str = ...,
        preferences: qwak.administration.account.v1.preferences_pb2.AccountPreferences | None = ...,
        type: qwak.administration.account.v1.account_pb2.AccountType.ValueType = ...,
        tier: qwak.administration.account.v1.account_pb2.AccountTier.ValueType = ...,
        accepted_terms: qwak.administration.account.v1.terms_pb2.AccountAcceptedTerms | None = ...,
        jfrog_tenant_spec: qwak.administration.account.v1.jfrog_tenant_details_pb2.JfrogTenantSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["accepted_terms", b"accepted_terms", "jfrog_tenant_spec", b"jfrog_tenant_spec", "preferences", b"preferences"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accepted_terms", b"accepted_terms", "account_id", b"account_id", "jfrog_tenant_spec", b"jfrog_tenant_spec", "preferences", b"preferences", "tier", b"tier", "type", b"type"]) -> None: ...

global___UpdateAccountRequest = UpdateAccountRequest

class UpdateAccountResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateAccountResponse = UpdateAccountResponse

class UpdateAccountPreferencesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    PREFERENCES_FIELD_NUMBER: builtins.int
    account_id: builtins.str
    """The account id to update"""
    @property
    def preferences(self) -> qwak.administration.account.v1.preferences_pb2.AccountPreferences:
        """New account preferences"""
    def __init__(
        self,
        *,
        account_id: builtins.str = ...,
        preferences: qwak.administration.account.v1.preferences_pb2.AccountPreferences | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["preferences", b"preferences"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "preferences", b"preferences"]) -> None: ...

global___UpdateAccountPreferencesRequest = UpdateAccountPreferencesRequest

class UpdateAccountPreferencesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateAccountPreferencesResponse = UpdateAccountPreferencesResponse

class UpdateAccountAcceptedTermsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    ACCEPTED_TERMS_FIELD_NUMBER: builtins.int
    account_id: builtins.str
    """The account id to update"""
    @property
    def accepted_terms(self) -> qwak.administration.account.v1.terms_pb2.AccountAcceptedTerms:
        """The accepted terms of the account"""
    def __init__(
        self,
        *,
        account_id: builtins.str = ...,
        accepted_terms: qwak.administration.account.v1.terms_pb2.AccountAcceptedTerms | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["accepted_terms", b"accepted_terms"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accepted_terms", b"accepted_terms", "account_id", b"account_id"]) -> None: ...

global___UpdateAccountAcceptedTermsRequest = UpdateAccountAcceptedTermsRequest

class UpdateAccountAcceptedTermsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateAccountAcceptedTermsResponse = UpdateAccountAcceptedTermsResponse

class AddAutoBindingRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    AUTO_BINDING_ACCOUNT_FIELD_NUMBER: builtins.int
    account_id: builtins.str
    """Account id to bound"""
    @property
    def auto_binding_account(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.administration.account.v1.account_pb2.AutoBindingRule]:
        """Rules"""
    def __init__(
        self,
        *,
        account_id: builtins.str = ...,
        auto_binding_account: collections.abc.Iterable[qwak.administration.account.v1.account_pb2.AutoBindingRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "auto_binding_account", b"auto_binding_account"]) -> None: ...

global___AddAutoBindingRequest = AddAutoBindingRequest

class AddAutoBindingResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTO_BINDING_ACCOUNT_FIELD_NUMBER: builtins.int
    @property
    def auto_binding_account(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.administration.account.v1.account_pb2.AutoBindingAccount]: ...
    def __init__(
        self,
        *,
        auto_binding_account: collections.abc.Iterable[qwak.administration.account.v1.account_pb2.AutoBindingAccount] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_binding_account", b"auto_binding_account"]) -> None: ...

global___AddAutoBindingResponse = AddAutoBindingResponse

class RemoveAutoBindingRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    AUTO_BINDING_ID_TO_REMOVE_FIELD_NUMBER: builtins.int
    account_id: builtins.str
    """Account id to remove binding for"""
    @property
    def auto_binding_id_to_remove(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Id list of auto bindings to remove"""
    def __init__(
        self,
        *,
        account_id: builtins.str = ...,
        auto_binding_id_to_remove: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "auto_binding_id_to_remove", b"auto_binding_id_to_remove"]) -> None: ...

global___RemoveAutoBindingRequest = RemoveAutoBindingRequest

class RemoveAutoBindingResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RemoveAutoBindingResponse = RemoveAutoBindingResponse

class GetAccountBriefRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    JFROG_TENANT_ID_FIELD_NUMBER: builtins.int
    account_id: builtins.str
    jfrog_tenant_id: builtins.str
    """The JFrog tenant id could be jpd_id for self-hosted"""
    def __init__(
        self,
        *,
        account_id: builtins.str = ...,
        jfrog_tenant_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "account_identifier", b"account_identifier", "jfrog_tenant_id", b"jfrog_tenant_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_id", b"account_id", "account_identifier", b"account_identifier", "jfrog_tenant_id", b"jfrog_tenant_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["account_identifier", b"account_identifier"]) -> typing_extensions.Literal["account_id", "jfrog_tenant_id"] | None: ...

global___GetAccountBriefRequest = GetAccountBriefRequest

class GetAccountBriefResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_BRIEF_FIELD_NUMBER: builtins.int
    @property
    def account_brief(self) -> qwak.administration.account.v1.account_pb2.AccountBrief: ...
    def __init__(
        self,
        *,
        account_brief: qwak.administration.account.v1.account_pb2.AccountBrief | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["account_brief", b"account_brief"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_brief", b"account_brief"]) -> None: ...

global___GetAccountBriefResponse = GetAccountBriefResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _UnaryOperatorType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _UnaryOperatorTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_UnaryOperatorType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNARY_OPERATOR_TYPE_INVALID: _UnaryOperatorType.ValueType  # 0
    UNARY_OPERATOR_TYPE_EXACT_MATCH: _UnaryOperatorType.ValueType  # 1
    UNARY_OPERATOR_TYPE_SAFE_REGEX_MATCH: _UnaryOperatorType.ValueType  # 2
    UNARY_OPERATOR_TYPE_PRESENT_MATCH: _UnaryOperatorType.ValueType  # 3
    UNARY_OPERATOR_TYPE_PREFIX_MATCH: _UnaryOperatorType.ValueType  # 4
    UNARY_OPERATOR_TYPE_SUFFIX_MATCH: _UnaryOperatorType.ValueType  # 5
    UNARY_OPERATOR_TYPE_CONTAINS_MATCH: _UnaryOperatorType.ValueType  # 6

class UnaryOperatorType(_UnaryOperatorType, metaclass=_UnaryOperatorTypeEnumTypeWrapper):
    """Unary operators available types"""

UNARY_OPERATOR_TYPE_INVALID: UnaryOperatorType.ValueType  # 0
UNARY_OPERATOR_TYPE_EXACT_MATCH: UnaryOperatorType.ValueType  # 1
UNARY_OPERATOR_TYPE_SAFE_REGEX_MATCH: UnaryOperatorType.ValueType  # 2
UNARY_OPERATOR_TYPE_PRESENT_MATCH: UnaryOperatorType.ValueType  # 3
UNARY_OPERATOR_TYPE_PREFIX_MATCH: UnaryOperatorType.ValueType  # 4
UNARY_OPERATOR_TYPE_SUFFIX_MATCH: UnaryOperatorType.ValueType  # 5
UNARY_OPERATOR_TYPE_CONTAINS_MATCH: UnaryOperatorType.ValueType  # 6
global___UnaryOperatorType = UnaryOperatorType

class _BinaryOperatorType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BinaryOperatorTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BinaryOperatorType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BINARY_OPERATOR_TYPE_INVALID: _BinaryOperatorType.ValueType  # 0
    BINARY_OPERATOR_TYPE_RANGE_MATCH: _BinaryOperatorType.ValueType  # 1

class BinaryOperatorType(_BinaryOperatorType, metaclass=_BinaryOperatorTypeEnumTypeWrapper):
    """Binary operators available types"""

BINARY_OPERATOR_TYPE_INVALID: BinaryOperatorType.ValueType  # 0
BINARY_OPERATOR_TYPE_RANGE_MATCH: BinaryOperatorType.ValueType  # 1
global___BinaryOperatorType = BinaryOperatorType

class AudienceEntry(google.protobuf.message.Message):
    """Describe audience entry with ID its equivalent ID for CRUD operation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    AUDIENCE_FIELD_NUMBER: builtins.int
    id: builtins.str
    @property
    def audience(self) -> global___Audience: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        audience: global___Audience | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["audience", b"audience"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience", b"audience", "id", b"id"]) -> None: ...

global___AudienceEntry = AudienceEntry

class Audience(google.protobuf.message.Message):
    """Specifies Condition based route configuration, If all conditions evaluated to true prediction request will route to routes config.
    For example: Condition check if prediction request include an header key, value which value is exactly "hello" than route
                 configuration will take effect.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvironmentRoutesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___EnvironmentAudienceRoutes: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___EnvironmentAudienceRoutes | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    ROUTES_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    MODIFIED_FIELD_NUMBER: builtins.int
    MODIFIED_BY_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ROUTES_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Audience name"""
    description: builtins.str
    """Audience description"""
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Condition]:
        """All conditions should evaluated to true"""
    @property
    def routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Route]:
        """If all evaluated to true the prediction will the routes"""
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Create date"""
    created_by: builtins.str
    """Created by"""
    @property
    def modified(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Update date"""
    modified_by: builtins.str
    """Updated by"""
    @property
    def environment_routes(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___EnvironmentAudienceRoutes]:
        """Routes by environment id"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        conditions: collections.abc.Iterable[global___Condition] | None = ...,
        routes: collections.abc.Iterable[global___Route] | None = ...,
        created: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_by: builtins.str = ...,
        modified: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        modified_by: builtins.str = ...,
        environment_routes: collections.abc.Mapping[builtins.str, global___EnvironmentAudienceRoutes] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["created", b"created", "modified", b"modified"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conditions", b"conditions", "created", b"created", "created_by", b"created_by", "description", b"description", "environment_routes", b"environment_routes", "modified", b"modified", "modified_by", b"modified_by", "name", b"name", "routes", b"routes"]) -> None: ...

global___Audience = Audience

class EnvironmentAudienceRoutes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTES_FIELD_NUMBER: builtins.int
    @property
    def routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Route]: ...
    def __init__(
        self,
        *,
        routes: collections.abc.Iterable[global___Route] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["routes", b"routes"]) -> None: ...

global___EnvironmentAudienceRoutes = EnvironmentAudienceRoutes

class AudienceRoutesEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCE_ID_FIELD_NUMBER: builtins.int
    AUDIENCE_NAME_FIELD_NUMBER: builtins.int
    ROUTES_FIELD_NUMBER: builtins.int
    ORDER_FIELD_NUMBER: builtins.int
    audience_id: builtins.str
    audience_name: builtins.str
    @property
    def routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Route]: ...
    order: builtins.int
    def __init__(
        self,
        *,
        audience_id: builtins.str = ...,
        audience_name: builtins.str = ...,
        routes: collections.abc.Iterable[global___Route] | None = ...,
        order: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience_id", b"audience_id", "audience_name", b"audience_name", "order", b"order", "routes", b"routes"]) -> None: ...

global___AudienceRoutesEntry = AudienceRoutesEntry

class Condition(google.protobuf.message.Message):
    """Condition which applied on prediction request header"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    BINARY_CONDITION_FIELD_NUMBER: builtins.int
    UNARY_CONDITION_FIELD_NUMBER: builtins.int
    INVERT_FIELD_NUMBER: builtins.int
    key: builtins.str
    """key to extract value for evaluation"""
    @property
    def binary_condition(self) -> global___BinaryCondition: ...
    @property
    def unary_condition(self) -> global___UnaryCondition: ...
    invert: builtins.bool
    """Condition evaluation should be inverted (For example False will be True)"""
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        binary_condition: global___BinaryCondition | None = ...,
        unary_condition: global___UnaryCondition | None = ...,
        invert: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["binary_condition", b"binary_condition", "condition", b"condition", "unary_condition", b"unary_condition"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["binary_condition", b"binary_condition", "condition", b"condition", "invert", b"invert", "key", b"key", "unary_condition", b"unary_condition"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["condition", b"condition"]) -> typing_extensions.Literal["binary_condition", "unary_condition"] | None: ...

global___Condition = Condition

class UnaryCondition(google.protobuf.message.Message):
    """Unary condition definition
    For example: unary_operator UnaryOperator.UNARY_OPERATOR_EXACT_MATCH with operand hello,
                 will check that header value will be exactly hello.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATOR_FIELD_NUMBER: builtins.int
    OPERAND_FIELD_NUMBER: builtins.int
    operator: global___UnaryOperatorType.ValueType
    operand: builtins.str
    def __init__(
        self,
        *,
        operator: global___UnaryOperatorType.ValueType = ...,
        operand: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["operand", b"operand", "operator", b"operator"]) -> None: ...

global___UnaryCondition = UnaryCondition

class BinaryCondition(google.protobuf.message.Message):
    """Binary condition definition
    For example: unary_operator BinaryOperatorType.BINARY_OPERATOR_TYPE_RANGE_MATCH with first_operand 1,
                 and second operand 3 will check that header value will be in range of 1-3 included)
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATOR_FIELD_NUMBER: builtins.int
    FIRST_OPERAND_FIELD_NUMBER: builtins.int
    SECOND_OPERAND_FIELD_NUMBER: builtins.int
    operator: global___BinaryOperatorType.ValueType
    first_operand: builtins.str
    second_operand: builtins.str
    def __init__(
        self,
        *,
        operator: global___BinaryOperatorType.ValueType = ...,
        first_operand: builtins.str = ...,
        second_operand: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["first_operand", b"first_operand", "operator", b"operator", "second_operand", b"second_operand"]) -> None: ...

global___BinaryCondition = BinaryCondition

class Route(google.protobuf.message.Message):
    """Route configuration to apply on specific variation if all conditions evaluated to true."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VARIATION_NAME_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    SHADOW_FIELD_NUMBER: builtins.int
    MODEL_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    AUDIENCE_ID_FIELD_NUMBER: builtins.int
    REQUEST_TIMEOUT_MS_FIELD_NUMBER: builtins.int
    variation_name: builtins.str
    """Deployment variation name"""
    weight: builtins.int
    """Weight of variation on splitting between other variations (Not percentage)"""
    shadow: builtins.bool
    """Shadow all traffic to this variation (All response from this variation will be ignored)"""
    model_id: builtins.str
    environment_id: builtins.str
    audience_id: builtins.str
    request_timeout_ms: builtins.int
    """Timeout of the request in ms"""
    def __init__(
        self,
        *,
        variation_name: builtins.str = ...,
        weight: builtins.int = ...,
        shadow: builtins.bool = ...,
        model_id: builtins.str = ...,
        environment_id: builtins.str = ...,
        audience_id: builtins.str = ...,
        request_timeout_ms: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience_id", b"audience_id", "environment_id", b"environment_id", "model_id", b"model_id", "request_timeout_ms", b"request_timeout_ms", "shadow", b"shadow", "variation_name", b"variation_name", "weight", b"weight"]) -> None: ...

global___Route = Route



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/admiral/secret/v0/account_secret.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.admiral.secret.v0 import secret_pb2 as qwak_dot_admiral_dot_secret_dot_v0_dot_secret__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+qwak/admiral/secret/v0/account_secret.proto\x12\x16qwak.admiral.secret.v0\x1a#qwak/admiral/secret/v0/secret.proto\x1a\x1cgoogle/protobuf/struct.proto\"H\n\x1d\x41\x63\x63ountSystemSecretIdentifier\x12\x12\n\naccount_id\x18\x01 \x01(\t\x12\x13\n\x0bsecret_name\x18\x02 \x01(\t\"^\n\x1d\x41\x63\x63ountSystemSecretDefinition\x12=\n\x04spec\x18\x01 \x01(\x0b\x32/.qwak.admiral.secret.v0.AccountSystemSecretSpec\"\xb5\x01\n\x17\x41\x63\x63ountSystemSecretSpec\x12Q\n\x12\x61\x63\x63ount_identifier\x18\x01 \x01(\x0b\x32\x35.qwak.admiral.secret.v0.AccountSystemSecretIdentifier\x12G\n\x15\x61\x63\x63ount_system_secret\x18\x02 \x01(\x0b\x32(.qwak.admiral.secret.v0.SystemSecretSpecB\x8c\x01\n\x1d\x63om.qwak.ai.admiral.secret.v0P\x01Zigithub.com/qwak-ai/qwak-platform/services/core/go/admiral/admiral-api/pb/qwak/admiral/secret/v0;secret_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.admiral.secret.v0.account_secret_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.qwak.ai.admiral.secret.v0P\001Zigithub.com/qwak-ai/qwak-platform/services/core/go/admiral/admiral-api/pb/qwak/admiral/secret/v0;secret_v0'
  _globals['_ACCOUNTSYSTEMSECRETIDENTIFIER']._serialized_start=138
  _globals['_ACCOUNTSYSTEMSECRETIDENTIFIER']._serialized_end=210
  _globals['_ACCOUNTSYSTEMSECRETDEFINITION']._serialized_start=212
  _globals['_ACCOUNTSYSTEMSECRETDEFINITION']._serialized_end=306
  _globals['_ACCOUNTSYSTEMSECRETSPEC']._serialized_start=309
  _globals['_ACCOUNTSYSTEMSECRETSPEC']._serialized_end=490
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/ecosystem/jfrog/v0/token.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#qwak/ecosystem/jfrog/v0/token.proto\x12\x1dqwak.ecosystem.jfrog.token.v0\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa5\x01\n\nJFrogToken\x12G\n\ndefinition\x18\x01 \x01(\x0b\x32\x33.qwak.ecosystem.jfrog.token.v0.JFrogTokenDefinition\x12N\n\x0etenant_details\x18\x02 \x01(\x0b\x32\x36.qwak.ecosystem.jfrog.token.v0.JFrogTokenTenantDetails\"/\n\x17JFrogTokenTenantDetails\x12\x14\n\x0cplatform_url\x18\x01 \x01(\t\"\xe4\x01\n\x14JFrogTokenDefinition\x12\r\n\x05token\x18\x01 \x01(\t\x12\x17\n\rrefresh_token\x18\x02 \x01(\tH\x00\x12\x35\n\x0f\x65xpiration_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x12\x0f\n\x07subject\x18\x04 \x01(\t\x12\x14\n\x0csubject_name\x18\x05 \x01(\t\x12\x10\n\x08token_id\x18\x06 \x01(\tB\x18\n\x16optional_refresh_tokenB\x1a\n\x18optional_expiration_time\"\x8c\x02\n\x0eJFrogTokenSpec\x12\x17\n\x0fjfrog_tenant_id\x18\x01 \x01(\t\x12V\n\x18subject_and_scope_source\x18\x02 \x01(\x0b\x32\x34.qwak.ecosystem.jfrog.token.v0.SubjectAndScopeSource\x12\x45\n\taudiences\x18\x03 \x01(\x0b\x32\x32.qwak.ecosystem.jfrog.token.v0.JFrogTokenAudiences\x12\x42\n\x08ttl_spec\x18\x04 \x01(\x0b\x32\x30.qwak.ecosystem.jfrog.token.v0.JFrogTokenTTLSpec\"\x89\x02\n\x1d\x41rtifactoryImagePullTokenSpec\x12\x17\n\x0fjfrog_tenant_id\x18\x01 \x01(\t\x12\x1a\n\x0erepository_key\x18\x02 \x01(\tB\x02\x18\x01\x12\x42\n\x08ttl_spec\x18\x03 \x01(\x0b\x32\x30.qwak.ecosystem.jfrog.token.v0.JFrogTokenTTLSpec\x12\x1b\n\x0frepository_keys\x18\x04 \x03(\tB\x02\x18\x01\x12R\n\x16repository_token_specs\x18\x05 \x03(\x0b\x32\x32.qwak.ecosystem.jfrog.token.v0.RepositoryTokenSpec\"\x97\x01\n\x16PersistTokenClaimsSpec\x12\x17\n\x0fjfrog_tenant_id\x18\x01 \x01(\t\x12\x11\n\x05token\x18\x02 \x01(\tB\x02\x18\x01\x12Q\n\x15token_scope_extension\x18\x03 \x01(\x0b\x32\x32.qwak.ecosystem.jfrog.token.v0.TokenScopeExtension\"m\n\x14JFrogTokenRevokeSpec\x12\x17\n\x0fjfrog_tenant_id\x18\x01 \x01(\t\x12\x0f\n\x05token\x18\x02 \x01(\tH\x00\x12\x12\n\x08token_id\x18\x03 \x01(\tH\x00\x42\x17\n\x15token_descriptor_type\"\xa8\x01\n\x13RepositoryTokenSpec\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x04type\x18\x02 \x01(\x0e\x32-.qwak.ecosystem.jfrog.token.v0.RepositoryType\x12G\n\x0bpermissions\x18\x03 \x03(\x0e\x32\x32.qwak.ecosystem.jfrog.token.v0.JFrogPermissionType\"{\n\x11JFrogTokenTTLSpec\x12\x35\n\x0f\x65xpiration_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x13\n\x0brefreshable\x18\x02 \x01(\x08\x42\x1a\n\x18optional_expiration_time\"\xf4\x01\n\x15SubjectAndScopeSource\x12\x13\n\x05token\x18\x01 \x01(\tB\x02\x18\x01H\x00\x12\x12\n\x08token_id\x18\x02 \x01(\tH\x00\x12S\n\x11subject_and_scope\x18\x03 \x01(\x0b\x32\x36.qwak.ecosystem.jfrog.token.v0.ExplicitSubjectAndScopeH\x00\x12S\n\x15token_scope_extension\x18\x04 \x01(\x0b\x32\x32.qwak.ecosystem.jfrog.token.v0.TokenScopeExtensionH\x00\x42\x08\n\x06source\"P\n\x17\x45xplicitSubjectAndScope\x12\x11\n\x07subject\x18\x01 \x01(\tH\x00\x12\x0e\n\x06scopes\x18\x02 \x01(\tB\x12\n\x10optional_subject\"[\n\x13JFrogTokenAudiences\x12\x44\n\taudiences\x18\x01 \x03(\x0b\x32\x31.qwak.ecosystem.jfrog.token.v0.JFrogTokenAudience\"\x86\x02\n\x12JFrogTokenAudience\x12L\n\x08jfrog_ml\x18\x01 \x01(\x0b\x32\x38.qwak.ecosystem.jfrog.token.v0.JFrogTokenAudienceJFrogMLH\x00\x12S\n\x0b\x61rtifactory\x18\x02 \x01(\x0b\x32<.qwak.ecosystem.jfrog.token.v0.JFrogTokenAudienceArtifactoryH\x00\x12\x45\n\x04xray\x18\x03 \x01(\x0b\x32\x35.qwak.ecosystem.jfrog.token.v0.JFrogTokenAudienceXRayH\x00\x42\x06\n\x04type\"\x1f\n\x1dJFrogTokenAudienceArtifactory\"\x18\n\x16JFrogTokenAudienceXRay\"\x1b\n\x19JFrogTokenAudienceJFrogML\"?\n\x13TokenScopeExtension\x12\r\n\x05token\x18\x01 \x01(\t\x12\x19\n\x11\x61\x64\x64itional_scopes\x18\x02 \x03(\t*H\n\x0eRepositoryType\x12\x1f\n\x1bREPOSITORY_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05LOCAL\x10\x01\x12\n\n\x06REMOTE\x10\x02*\x8e\x01\n\x13JFrogPermissionType\x12%\n!JFROG_PERMISSION_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04READ\x10\x01\x12\t\n\x05WRITE\x10\x02\x12\n\n\x06\x44\x45LETE\x10\x03\x12\x0c\n\x08\x41NNOTATE\x10\x04\x12\x0b\n\x07\x45XECUTE\x10\x05\x12\x08\n\x04SCAN\x10\x06\x12\n\n\x06MANAGE\x10\x07\x42\xb7\x01\n\x1a\x63om.qwak.ai.jfrog.token.v0P\x01Z\x96\x01github.com/qwak-ai/qwak-platform/services/shared/java/libs/qwak-common/qwak-common-api/qwak-platform-ecosystem-api/pb/qwak/ecosystem/jfrog/v0;jfrog_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.ecosystem.jfrog.v0.token_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032com.qwak.ai.jfrog.token.v0P\001Z\226\001github.com/qwak-ai/qwak-platform/services/shared/java/libs/qwak-common/qwak-common-api/qwak-platform-ecosystem-api/pb/qwak/ecosystem/jfrog/v0;jfrog_v0'
  _ARTIFACTORYIMAGEPULLTOKENSPEC.fields_by_name['repository_key']._options = None
  _ARTIFACTORYIMAGEPULLTOKENSPEC.fields_by_name['repository_key']._serialized_options = b'\030\001'
  _ARTIFACTORYIMAGEPULLTOKENSPEC.fields_by_name['repository_keys']._options = None
  _ARTIFACTORYIMAGEPULLTOKENSPEC.fields_by_name['repository_keys']._serialized_options = b'\030\001'
  _PERSISTTOKENCLAIMSSPEC.fields_by_name['token']._options = None
  _PERSISTTOKENCLAIMSSPEC.fields_by_name['token']._serialized_options = b'\030\001'
  _SUBJECTANDSCOPESOURCE.fields_by_name['token']._options = None
  _SUBJECTANDSCOPESOURCE.fields_by_name['token']._serialized_options = b'\030\001'
  _globals['_REPOSITORYTYPE']._serialized_start=2491
  _globals['_REPOSITORYTYPE']._serialized_end=2563
  _globals['_JFROGPERMISSIONTYPE']._serialized_start=2566
  _globals['_JFROGPERMISSIONTYPE']._serialized_end=2708
  _globals['_JFROGTOKEN']._serialized_start=104
  _globals['_JFROGTOKEN']._serialized_end=269
  _globals['_JFROGTOKENTENANTDETAILS']._serialized_start=271
  _globals['_JFROGTOKENTENANTDETAILS']._serialized_end=318
  _globals['_JFROGTOKENDEFINITION']._serialized_start=321
  _globals['_JFROGTOKENDEFINITION']._serialized_end=549
  _globals['_JFROGTOKENSPEC']._serialized_start=552
  _globals['_JFROGTOKENSPEC']._serialized_end=820
  _globals['_ARTIFACTORYIMAGEPULLTOKENSPEC']._serialized_start=823
  _globals['_ARTIFACTORYIMAGEPULLTOKENSPEC']._serialized_end=1088
  _globals['_PERSISTTOKENCLAIMSSPEC']._serialized_start=1091
  _globals['_PERSISTTOKENCLAIMSSPEC']._serialized_end=1242
  _globals['_JFROGTOKENREVOKESPEC']._serialized_start=1244
  _globals['_JFROGTOKENREVOKESPEC']._serialized_end=1353
  _globals['_REPOSITORYTOKENSPEC']._serialized_start=1356
  _globals['_REPOSITORYTOKENSPEC']._serialized_end=1524
  _globals['_JFROGTOKENTTLSPEC']._serialized_start=1526
  _globals['_JFROGTOKENTTLSPEC']._serialized_end=1649
  _globals['_SUBJECTANDSCOPESOURCE']._serialized_start=1652
  _globals['_SUBJECTANDSCOPESOURCE']._serialized_end=1896
  _globals['_EXPLICITSUBJECTANDSCOPE']._serialized_start=1898
  _globals['_EXPLICITSUBJECTANDSCOPE']._serialized_end=1978
  _globals['_JFROGTOKENAUDIENCES']._serialized_start=1980
  _globals['_JFROGTOKENAUDIENCES']._serialized_end=2071
  _globals['_JFROGTOKENAUDIENCE']._serialized_start=2074
  _globals['_JFROGTOKENAUDIENCE']._serialized_end=2336
  _globals['_JFROGTOKENAUDIENCEARTIFACTORY']._serialized_start=2338
  _globals['_JFROGTOKENAUDIENCEARTIFACTORY']._serialized_end=2369
  _globals['_JFROGTOKENAUDIENCEXRAY']._serialized_start=2371
  _globals['_JFROGTOKENAUDIENCEXRAY']._serialized_end=2395
  _globals['_JFROGTOKENAUDIENCEJFROGML']._serialized_start=2397
  _globals['_JFROGTOKENAUDIENCEJFROGML']._serialized_end=2424
  _globals['_TOKENSCOPEEXTENSION']._serialized_start=2426
  _globals['_TOKENSCOPEEXTENSION']._serialized_end=2489
# @@protoc_insertion_point(module_scope)



from typing import Optional

from _qwak_proto.qwak.instance_template.instance_template_pb2 import InstanceType
from qwak.clients.instance_template.client import InstanceTemplateManagementClient
from qwak.exceptions import QwakException
from qwak.inner.provider import Provider

INVALID_TEMPLATE_ID_ERROR_FORMAT = (
    "Invalid instance: {template_id}. Valid instances are: {cpu_templates}. "
    "For GPU instances you can use {gpu_templates}."
)


def verify_template_id(
    template_id: str,
    instance_template_client: InstanceTemplateManagementClient,
    provider: Optional[Provider] = None,
) -> None:
    all_templates = instance_template_client.list_instance_templates()
    valid_templates = [template for template in all_templates if template.enabled]
    if provider == Provider.AWS:
        valid_templates = [
            template for template in valid_templates if template.aws_supported
        ]
    elif provider == Provider.GCP:
        valid_templates = [
            template for template in valid_templates if template.gcp_supported
        ]

    existing_templates = {template.id: template for template in valid_templates}
    if template_id not in existing_templates.keys():
        cpu_template_ids = [
            template.id
            for template in sorted(valid_templates, key=lambda template: template.order)
            if template.instance_type == InstanceType.INSTANCE_TYPE_CPU
        ]
        gpu_template_ids = [
            template.id
            for template in sorted(valid_templates, key=lambda template: template.order)
            if template.instance_type == InstanceType.INSTANCE_TYPE_GPU
        ]
        raise QwakException(
            INVALID_TEMPLATE_ID_ERROR_FORMAT.format(
                template_id=template_id,
                cpu_templates=", ".join(cpu_template_ids),
                gpu_templates=", ".join(gpu_template_ids),
            )
        )



from dataclasses import dataclass, field
from enum import Enum

from _qwak_proto.qwak.build.v1.build_pb2 import ParameterFilter as ParameterFilterProto


class ParameterOperatorType(Enum):
    PARAMETER_OPERATOR_TYPE_INVALID = 0
    PARAMETER_OPERATOR_TYPE_EQUALS = 1
    PARAMETER_OPERATOR_TYPE_NOT_EQUALS = 2


@dataclass
class ParameterFilter:
    parameter_name: str = field(default=None)
    parameter_value: str = field(default=None)
    operator: ParameterOperatorType = field(
        default=ParameterOperatorType.PARAMETER_OPERATOR_TYPE_INVALID
    )

    def to_proto(self):
        return ParameterFilterProto(
            parameter_name=self.parameter_name,
            parameter_value=self.parameter_value,
            operator=self.operator.value,
        )

    @staticmethod
    def from_proto(parameter_filter_proto: ParameterFilterProto):
        return ParameterFilter(
            parameter_name=parameter_filter_proto.parameter_name,
            parameter_value=parameter_filter_proto.parameter_value,
            operator=parameter_filter_proto.operator,
        )



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.administration.v0.environments import environment_service_pb2 as qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2


class EnvironmentServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateEnvironment = channel.unary_unary(
                '/qwak.administration.environment.EnvironmentService/CreateEnvironment',
                request_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.CreateEnvironmentRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.CreateEnvironmentResponse.FromString,
                )
        self.GetEnvironment = channel.unary_unary(
                '/qwak.administration.environment.EnvironmentService/GetEnvironment',
                request_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.GetEnvironmentRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.GetEnvironmentResponse.FromString,
                )
        self.UpdateEnvironmentConfiguration = channel.unary_unary(
                '/qwak.administration.environment.EnvironmentService/UpdateEnvironmentConfiguration',
                request_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.UpdateEnvironmentConfigurationRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.UpdateEnvironmentConfigurationResponse.FromString,
                )
        self.UpdateEnvironmentPersonalization = channel.unary_unary(
                '/qwak.administration.environment.EnvironmentService/UpdateEnvironmentPersonalization',
                request_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.UpdateEnvironmentPersonalizationRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.UpdateEnvironmentPersonalizationResponse.FromString,
                )
        self.ListEnvironments = channel.unary_unary(
                '/qwak.administration.environment.EnvironmentService/ListEnvironments',
                request_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.ListEnvironmentsRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.ListEnvironmentsResponse.FromString,
                )
        self.GetEnvironmentApplicationUserCredentials = channel.unary_unary(
                '/qwak.administration.environment.EnvironmentService/GetEnvironmentApplicationUserCredentials',
                request_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.GetEnvironmentApplicationUserCredentialsRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.GetEnvironmentApplicationUserCredentialsResponse.FromString,
                )
        self.SetEnvironmentApplicationUserCredentials = channel.unary_unary(
                '/qwak.administration.environment.EnvironmentService/SetEnvironmentApplicationUserCredentials',
                request_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.SetEnvironmentApplicationUserCredentialsRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.SetEnvironmentApplicationUserCredentialsResponse.FromString,
                )


class EnvironmentServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateEnvironment(self, request, context):
        """Create a environment in Qwak system
        The operation initiates of process of environment creation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEnvironment(self, request, context):
        """Get an environment information
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEnvironmentConfiguration(self, request, context):
        """Update a configuration of an environment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEnvironmentPersonalization(self, request, context):
        """Update a personalization of an environment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListEnvironments(self, request, context):
        """List all Environments registered to Qwak
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEnvironmentApplicationUserCredentials(self, request, context):
        """Get qwak credentials for environment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetEnvironmentApplicationUserCredentials(self, request, context):
        """Get qwak credentials for environment
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_EnvironmentServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateEnvironment,
                    request_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.CreateEnvironmentRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.CreateEnvironmentResponse.SerializeToString,
            ),
            'GetEnvironment': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEnvironment,
                    request_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.GetEnvironmentRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.GetEnvironmentResponse.SerializeToString,
            ),
            'UpdateEnvironmentConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEnvironmentConfiguration,
                    request_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.UpdateEnvironmentConfigurationRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.UpdateEnvironmentConfigurationResponse.SerializeToString,
            ),
            'UpdateEnvironmentPersonalization': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEnvironmentPersonalization,
                    request_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.UpdateEnvironmentPersonalizationRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.UpdateEnvironmentPersonalizationResponse.SerializeToString,
            ),
            'ListEnvironments': grpc.unary_unary_rpc_method_handler(
                    servicer.ListEnvironments,
                    request_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.ListEnvironmentsRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.ListEnvironmentsResponse.SerializeToString,
            ),
            'GetEnvironmentApplicationUserCredentials': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEnvironmentApplicationUserCredentials,
                    request_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.GetEnvironmentApplicationUserCredentialsRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.GetEnvironmentApplicationUserCredentialsResponse.SerializeToString,
            ),
            'SetEnvironmentApplicationUserCredentials': grpc.unary_unary_rpc_method_handler(
                    servicer.SetEnvironmentApplicationUserCredentials,
                    request_deserializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.SetEnvironmentApplicationUserCredentialsRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.SetEnvironmentApplicationUserCredentialsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.administration.environment.EnvironmentService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class EnvironmentService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.environment.EnvironmentService/CreateEnvironment',
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.CreateEnvironmentRequest.SerializeToString,
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.CreateEnvironmentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEnvironment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.environment.EnvironmentService/GetEnvironment',
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.GetEnvironmentRequest.SerializeToString,
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.GetEnvironmentResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEnvironmentConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.environment.EnvironmentService/UpdateEnvironmentConfiguration',
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.UpdateEnvironmentConfigurationRequest.SerializeToString,
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.UpdateEnvironmentConfigurationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateEnvironmentPersonalization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.environment.EnvironmentService/UpdateEnvironmentPersonalization',
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.UpdateEnvironmentPersonalizationRequest.SerializeToString,
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.UpdateEnvironmentPersonalizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListEnvironments(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.environment.EnvironmentService/ListEnvironments',
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.ListEnvironmentsRequest.SerializeToString,
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.ListEnvironmentsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEnvironmentApplicationUserCredentials(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.environment.EnvironmentService/GetEnvironmentApplicationUserCredentials',
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.GetEnvironmentApplicationUserCredentialsRequest.SerializeToString,
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.GetEnvironmentApplicationUserCredentialsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetEnvironmentApplicationUserCredentials(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.environment.EnvironmentService/SetEnvironmentApplicationUserCredentials',
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.SetEnvironmentApplicationUserCredentialsRequest.SerializeToString,
            qwak_dot_administration_dot_v0_dot_environments_dot_environment__service__pb2.SetEnvironmentApplicationUserCredentialsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
